# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quote/quote_enum.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='quote/quote_enum.proto',
  package='quote.tag',
  syntax='proto3',
  serialized_options=_b('\242\002\003QEN'),
  serialized_pb=_b('\n\x16quote/quote_enum.proto\x12\tquote.tag*\x86\x01\n\x0e\x44\x65pthLevelType\x12\x15\n\x11\x44\x65pthLevelType_L0\x10\x00\x12\x15\n\x11\x44\x65pthLevelType_L1\x10\x01\x12\x15\n\x11\x44\x65pthLevelType_L5\x10\x02\x12\x16\n\x12\x44\x65pthLevelType_L10\x10\x03\x12\x17\n\x13\x44\x65pthLevelType_FULL\x10\x04*/\n\x08SideType\x12\x10\n\x0cSideType_Buy\x10\x00\x12\x11\n\rSideType_Sell\x10\x01*\xbe\x03\n\x0eInstrumentType\x12\x18\n\x14InstrumentType_Stock\x10\x00\x12\x19\n\x15InstrumentType_Future\x10\x01\x12\x19\n\x15InstrumentType_Option\x10\x02\x12\x1f\n\x1bInstrumentType_FutureOption\x10\x03\x12\x17\n\x13InstrumentType_Bond\x10\x04\x12\x15\n\x11InstrumentType_FX\x10\x05\x12\x17\n\x13InstrumentType_Repo\x10\x06\x12\x18\n\x14InstrumentType_Index\x10\x07\x12\x16\n\x12InstrumentType_ETF\x10\x08\x12\x1b\n\x17InstrumentType_MultiLeg\x10\t\x12\x1c\n\x18InstrumentType_Synthetic\x10\n\x12\x1a\n\x16InstrumentType_Warrant\x10\x0b\x12\x17\n\x13InstrumentType_Spot\x10\x0c\x12\x1b\n\x17InstrumentType_Standard\x10\r\x12\x17\n\x13InstrumentType_Fund\x10\x0e\x12\x1a\n\x16InstrumentType_Unknown\x10\x1e*\xb9\x02\n\x07\x42\x61rType\x12\x10\n\x0c\x42\x61rType_Time\x10\x00\x12\x10\n\x0c\x42\x61rType_Tick\x10\x01\x12\x12\n\x0e\x42\x61rType_Volume\x10\x02\x12\x11\n\rBarType_Range\x10\x03\x12\x13\n\x0f\x42\x61rType_Session\x10\x04\x12\x0f\n\x0b\x42\x61rType_Min\x10\x05\x12\x15\n\x11\x42\x61rType_Five_Mins\x10\x06\x12\x18\n\x14\x42\x61rType_Fifteen_Mins\x10\x07\x12\x17\n\x13\x42\x61rType_Thirty_Mins\x10\x08\x12\x16\n\x12\x42\x61rType_Sixty_Mins\x10\t\x12\x0f\n\x0b\x42\x61rType_Day\x10\n\x12\x10\n\x0c\x42\x61rType_Week\x10\x0b\x12\x11\n\rBarType_Month\x10\x0c\x12\x13\n\x0f\x42\x61rType_Quarter\x10\r\x12\x10\n\x0c\x42\x61rType_Year\x10\x0e*\xc4\x02\n\nPeriodType\x12\x12\n\x0ePeriodType_Now\x10\x00\x12\x15\n\x11PeriodType_Hisnow\x10\x01\x12\x15\n\x10PeriodType_Trace\x10\x80 \x12\x1a\n\x15PeriodType_One_Minute\x10\x81`\x12\x1c\n\x17PeriodType_Five_Minutes\x10\x85`\x12\x1f\n\x1aPeriodType_Fifteen_Minutes\x10\x8f`\x12\x1e\n\x19PeriodType_Thirty_Minutes\x10\x9e`\x12\x1d\n\x18PeriodType_Sixty_Minutes\x10\xbc`\x12\x14\n\x0ePeriodType_Day\x10\x80\x80\x01\x12\x15\n\x0fPeriodType_Week\x10\x81\xa0\x01\x12\x16\n\x10PeriodType_Month\x10\x81\xc0\x01\x12\x15\n\x0fPeriodType_Year\x10\x81\xe0\x01*\xb5\x02\n\rDataObjetType\x12\x1a\n\x16\x44\x61taObjetType_Undefine\x10\x00\x12\x16\n\x12\x44\x61taObjetType_Tick\x10\x01\x12\x15\n\x11\x44\x61taObjetType_Bid\x10\x02\x12\x15\n\x11\x44\x61taObjetType_Ask\x10\x03\x12\x17\n\x13\x44\x61taObjetType_Trade\x10\x04\x12\x17\n\x13\x44\x61taObjetType_Order\x10\x05\x12\x15\n\x11\x44\x61taObjetType_Bar\x10\x06\x12\x1d\n\x19\x44\x61taObjectType_OrderQueue\x10\x07\x12\x18\n\x14\x44\x61taObjetType_Level2\x10\x08\x12 \n\x1c\x44\x61taObjetType_Level2Snapshot\x10\t\x12\x1e\n\x1a\x44\x61taObjetType_Level2Update\x10\nB\x06\xa2\x02\x03QENb\x06proto3')
)

_DEPTHLEVELTYPE = _descriptor.EnumDescriptor(
  name='DepthLevelType',
  full_name='quote.tag.DepthLevelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DepthLevelType_L0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DepthLevelType_L1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DepthLevelType_L5', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DepthLevelType_L10', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DepthLevelType_FULL', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=38,
  serialized_end=172,
)
_sym_db.RegisterEnumDescriptor(_DEPTHLEVELTYPE)

DepthLevelType = enum_type_wrapper.EnumTypeWrapper(_DEPTHLEVELTYPE)
_SIDETYPE = _descriptor.EnumDescriptor(
  name='SideType',
  full_name='quote.tag.SideType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SideType_Buy', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SideType_Sell', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=174,
  serialized_end=221,
)
_sym_db.RegisterEnumDescriptor(_SIDETYPE)

SideType = enum_type_wrapper.EnumTypeWrapper(_SIDETYPE)
_INSTRUMENTTYPE = _descriptor.EnumDescriptor(
  name='InstrumentType',
  full_name='quote.tag.InstrumentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Stock', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Future', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Option', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_FutureOption', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Bond', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_FX', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Repo', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Index', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_ETF', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_MultiLeg', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Synthetic', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Warrant', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Spot', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Standard', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Fund', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InstrumentType_Unknown', index=15, number=30,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=224,
  serialized_end=670,
)
_sym_db.RegisterEnumDescriptor(_INSTRUMENTTYPE)

InstrumentType = enum_type_wrapper.EnumTypeWrapper(_INSTRUMENTTYPE)
_BARTYPE = _descriptor.EnumDescriptor(
  name='BarType',
  full_name='quote.tag.BarType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BarType_Time', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Tick', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Volume', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Range', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Session', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Min', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Five_Mins', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Fifteen_Mins', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Thirty_Mins', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Sixty_Mins', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Day', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Week', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Month', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Quarter', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BarType_Year', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=673,
  serialized_end=986,
)
_sym_db.RegisterEnumDescriptor(_BARTYPE)

BarType = enum_type_wrapper.EnumTypeWrapper(_BARTYPE)
_PERIODTYPE = _descriptor.EnumDescriptor(
  name='PeriodType',
  full_name='quote.tag.PeriodType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Now', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Hisnow', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Trace', index=2, number=4096,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_One_Minute', index=3, number=12289,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Five_Minutes', index=4, number=12293,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Fifteen_Minutes', index=5, number=12303,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Thirty_Minutes', index=6, number=12318,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Sixty_Minutes', index=7, number=12348,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Day', index=8, number=16384,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Week', index=9, number=20481,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Month', index=10, number=24577,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PeriodType_Year', index=11, number=28673,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=989,
  serialized_end=1313,
)
_sym_db.RegisterEnumDescriptor(_PERIODTYPE)

PeriodType = enum_type_wrapper.EnumTypeWrapper(_PERIODTYPE)
_DATAOBJETTYPE = _descriptor.EnumDescriptor(
  name='DataObjetType',
  full_name='quote.tag.DataObjetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Undefine', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Tick', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Bid', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Ask', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Trade', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Order', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Bar', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjectType_OrderQueue', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Level2', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Level2Snapshot', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataObjetType_Level2Update', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1316,
  serialized_end=1625,
)
_sym_db.RegisterEnumDescriptor(_DATAOBJETTYPE)

DataObjetType = enum_type_wrapper.EnumTypeWrapper(_DATAOBJETTYPE)
DepthLevelType_L0 = 0
DepthLevelType_L1 = 1
DepthLevelType_L5 = 2
DepthLevelType_L10 = 3
DepthLevelType_FULL = 4
SideType_Buy = 0
SideType_Sell = 1
InstrumentType_Stock = 0
InstrumentType_Future = 1
InstrumentType_Option = 2
InstrumentType_FutureOption = 3
InstrumentType_Bond = 4
InstrumentType_FX = 5
InstrumentType_Repo = 6
InstrumentType_Index = 7
InstrumentType_ETF = 8
InstrumentType_MultiLeg = 9
InstrumentType_Synthetic = 10
InstrumentType_Warrant = 11
InstrumentType_Spot = 12
InstrumentType_Standard = 13
InstrumentType_Fund = 14
InstrumentType_Unknown = 30
BarType_Time = 0
BarType_Tick = 1
BarType_Volume = 2
BarType_Range = 3
BarType_Session = 4
BarType_Min = 5
BarType_Five_Mins = 6
BarType_Fifteen_Mins = 7
BarType_Thirty_Mins = 8
BarType_Sixty_Mins = 9
BarType_Day = 10
BarType_Week = 11
BarType_Month = 12
BarType_Quarter = 13
BarType_Year = 14
PeriodType_Now = 0
PeriodType_Hisnow = 1
PeriodType_Trace = 4096
PeriodType_One_Minute = 12289
PeriodType_Five_Minutes = 12293
PeriodType_Fifteen_Minutes = 12303
PeriodType_Thirty_Minutes = 12318
PeriodType_Sixty_Minutes = 12348
PeriodType_Day = 16384
PeriodType_Week = 20481
PeriodType_Month = 24577
PeriodType_Year = 28673
DataObjetType_Undefine = 0
DataObjetType_Tick = 1
DataObjetType_Bid = 2
DataObjetType_Ask = 3
DataObjetType_Trade = 4
DataObjetType_Order = 5
DataObjetType_Bar = 6
DataObjectType_OrderQueue = 7
DataObjetType_Level2 = 8
DataObjetType_Level2Snapshot = 9
DataObjetType_Level2Update = 10


DESCRIPTOR.enum_types_by_name['DepthLevelType'] = _DEPTHLEVELTYPE
DESCRIPTOR.enum_types_by_name['SideType'] = _SIDETYPE
DESCRIPTOR.enum_types_by_name['InstrumentType'] = _INSTRUMENTTYPE
DESCRIPTOR.enum_types_by_name['BarType'] = _BARTYPE
DESCRIPTOR.enum_types_by_name['PeriodType'] = _PERIODTYPE
DESCRIPTOR.enum_types_by_name['DataObjetType'] = _DATAOBJETTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
