# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trade/trade_stock.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from trade import trade_enum_pb2 as trade_dot_trade__enum__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='trade/trade_stock.proto',
  package='trade.stock',
  syntax='proto3',
  serialized_options=_b('\242\002\003TST'),
  serialized_pb=_b('\n\x17trade/trade_stock.proto\x12\x0btrade.stock\x1a\x16trade/trade_enum.proto\"\x80\x01\n\rQueryOrderReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x12\n\nbegin_time\x18\x04 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03\x12\x14\n\x0cinvestor_key\x18\x06 \x01(\x04\"\x93\x01\n\x0eQueryReportReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x10\n\x08trade_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12\x12\n\nbegin_time\x18\x05 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x03\x12\x14\n\x0cinvestor_key\x18\x07 \x01(\x04\"8\n\rQueryAssetReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x02 \x01(\x04\"\x8a\x04\n\rQueryAssetRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12)\n\x08\x63urrency\x18\x02 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x14\n\x0c\x62\x65gin_amount\x18\x03 \x01(\x01\x12\x0f\n\x07\x64\x65posit\x18\x04 \x01(\x01\x12\x10\n\x08withdraw\x18\x05 \x01(\x01\x12\x16\n\x0e\x63urrent_amount\x18\x06 \x01(\x01\x12\x14\n\x0ctotal_amount\x18\x07 \x01(\x01\x12\x11\n\tavailable\x18\x08 \x01(\x01\x12\x14\n\x0cwithdrawable\x18\t \x01(\x01\x12\x18\n\x10total_buy_amount\x18\n \x01(\x01\x12\x15\n\rtotal_buy_fee\x18\x0b \x01(\x01\x12\x19\n\x11total_sell_amount\x18\x0c \x01(\x01\x12\x16\n\x0etotal_sell_fee\x18\r \x01(\x01\x12\x15\n\rfrozen_margin\x18\x0e \x01(\x01\x12\x15\n\rcaptial_asset\x18\x0f \x01(\x01\x12\x16\n\x0esecurity_asset\x18\x10 \x01(\x01\x12\x14\n\x0c\x63lose_profit\x18\x11 \x01(\x01\x12\x12\n\ncommission\x18\x12 \x01(\x01\x12\x17\n\x0fposition_profit\x18\x13 \x01(\x01\x12\x14\n\x0c\x66loat_profit\x18\x14 \x01(\x01\x12\x12\n\nin_transit\x18\x15 \x01(\x01\x12\x14\n\x0cinvestor_key\x18\x16 \x01(\x04\"K\n\x10QueryPositionReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x03 \x01(\x04\"\xcc\x03\n\x10QueryPositionRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x14\n\x0cstock_holder\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x13\n\x0bsymbol_name\x18\x04 \x01(\x0c\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\x16\n\x0equantity_begin\x18\x06 \x01(\x03\x12\x1d\n\x15quantity_begin_frozen\x18\x07 \x01(\x03\x12\x1a\n\x12quantity_buy_today\x18\x08 \x01(\x03\x12!\n\x19quantity_buy_frozen_today\x18\t \x01(\x03\x12\x1b\n\x13quantity_sell_today\x18\n \x01(\x03\x12\"\n\x1aquantity_sell_frozen_today\x18\x0b \x01(\x03\x12\x1a\n\x12quantity_available\x18\x0c \x01(\x03\x12\x18\n\x10quantity_current\x18\r \x01(\x03\x12\x12\n\nlast_price\x18\x0e \x01(\x01\x12\x12\n\ncost_price\x18\x0f \x01(\x01\x12\x14\n\x0c\x66loat_profit\x18\x10 \x01(\x01\x12\x14\n\x0cinvestor_key\x18\x11 \x01(\x04\"\x82\x04\n\x0eOrderInsertReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\r\n\x05price\x18\x06 \x01(\x01\x12\x10\n\x08quantity\x18\x07 \x01(\x03\x12(\n\nprice_type\x18\x08 \x01(\x0e\x32\x14.trade.tag.PriceType\x12%\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\n \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x14\n\x0corder_source\x18\x0b \x01(\t\x12(\n\norder_type\x18\x0c \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x14\n\x0cinvestor_key\x18\r \x01(\x04\x12\x16\n\x0einstruction_id\x18\x0e \x01(\x03\x12\x14\n\x0cportfolio_id\x18\x0f \x01(\x03\x12\x10\n\x08\x63ombi_no\x18\x10 \x01(\x03\x12\x0f\n\x07user_id\x18\x11 \x01(\t\x12\x17\n\x0forder_deal_flag\x18\x12 \x01(\x03\x12\x16\n\x0einstitution_id\x18\x13 \x01(\x03\"\xf0\x03\n\x0eOrderInsertRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\r\n\x05price\x18\x06 \x01(\x01\x12\x10\n\x08quantity\x18\x07 \x01(\x03\x12(\n\nprice_type\x18\x08 \x01(\x0e\x32\x14.trade.tag.PriceType\x12%\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\n \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x14\n\x0corder_source\x18\x0b \x01(\t\x12(\n\norder_type\x18\x0c \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x0c\n\x04\x63ode\x18\r \x01(\x05\x12\x0f\n\x07message\x18\x0e \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x0f \x01(\x04\x12\x16\n\x0einstruction_id\x18\x10 \x01(\x03\x12\x14\n\x0cportfolio_id\x18\x11 \x01(\x03\x12\x10\n\x08\x63ombi_no\x18\x12 \x01(\x03\x12\x0f\n\x07user_id\x18\x13 \x01(\t\"\xae\x01\n\x0eOrderCancelReq\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x1d\n\x15local_cancel_order_no\x18\x03 \x01(\t\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x04 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x05 \x01(\x04\x12)\n\x08\x65xchange\x18\x06 \x01(\x0e\x32\x17.trade.tag.ExchangeType\"\xa2\x01\n\x0eOrderCancelRsp\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x03 \x01(\t\x12\x1d\n\x15local_cancel_order_no\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x06 \x01(\x05\x12\x14\n\x0cinvestor_key\x18\x07 \x01(\x04\"`\n\x13OrderCancelFailInfo\x12*\n\x05order\x18\x01 \x01(\x0b\x32\x1b.trade.stock.OrderCancelReq\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"\xf9\x06\n\tOrderInfo\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x02 \x01(\t\x12\x1d\n\x15local_cancel_order_no\x18\x03 \x01(\t\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x04 \x01(\t\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12)\n\x08\x65xchange\x18\x06 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\r\n\x05price\x18\x07 \x01(\x01\x12\x10\n\x08quantity\x18\x08 \x01(\x03\x12(\n\nprice_type\x18\t \x01(\x0e\x32\x14.trade.tag.PriceType\x12%\n\x06\x61\x63tion\x18\n \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\x0b \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x17\n\x0fquantity_traded\x18\x0c \x01(\x03\x12\x15\n\rquantity_left\x18\r \x01(\x03\x12\x13\n\x0binsert_time\x18\x0e \x01(\x03\x12\x13\n\x0bupdate_time\x18\x0f \x01(\x03\x12\x13\n\x0b\x63\x61ncel_time\x18\x10 \x01(\x03\x12\x15\n\rfrozen_margin\x18\x11 \x01(\x01\x12\x14\n\x0ctrade_amount\x18\x12 \x01(\x01\x12\x30\n\x0corder_status\x18\x13 \x01(\x0e\x32\x1a.trade.tag.OrderStatusType\x12(\n\norder_type\x18\x14 \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x11\n\tclient_id\x18\x15 \x01(\t\x12\x0c\n\x04\x63ode\x18\x16 \x01(\x05\x12\x0f\n\x07message\x18\x17 \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x18 \x01(\x04\x12\x11\n\tavg_price\x18\x19 \x01(\x01\x12\x13\n\x0bsymbol_name\x18\x1a \x01(\x0c\x12\x16\n\x0einstruction_id\x18\x1b \x01(\x03\x12\x14\n\x0cportfolio_id\x18\x1c \x01(\x03\x12\x10\n\x08\x63ombi_no\x18\x1d \x01(\x03\x12\x0f\n\x07user_id\x18\x1e \x01(\t\x12\x18\n\x10\x66irst_trade_time\x18\x1f \x01(\x03\x12\x19\n\x11quantity_canceled\x18  \x01(\x03\x12\x16\n\x0einstitution_id\x18! \x01(\x03\x12\x0e\n\x06seq_no\x18\" \x01(\x03\x12\x17\n\x0forder_deal_flag\x18# \x01(\x03\"\xc9\x03\n\x0fTradeReportInfo\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12)\n\x08\x65xchange\x18\x05 \x01(\x0e\x32\x17.trade.tag.ExchangeType\x12\x10\n\x08trade_no\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\x01\x12\x10\n\x08quantity\x18\x08 \x01(\x03\x12\x12\n\ntrade_time\x18\t \x01(\x03\x12\x14\n\x0ctrade_amount\x18\n \x01(\x01\x12\x14\n\x0creport_index\x18\x0b \x01(\x04\x12(\n\ntrade_type\x18\x0c \x01(\x0e\x32\x14.trade.tag.TradeType\x12%\n\x06\x61\x63tion\x18\r \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\rbusiness_type\x18\x0e \x01(\x0e\x32\x17.trade.tag.BusinessType\x12\x14\n\x0cinvestor_key\x18\x0f \x01(\x04\x12\x13\n\x0bsymbol_name\x18\x10 \x01(\x0c\x12\x0f\n\x07user_id\x18\x11 \x01(\t\x12\x0e\n\x06seq_no\x18\x12 \x01(\x03\x42\x06\xa2\x02\x03TSTb\x06proto3')
  ,
  dependencies=[trade_dot_trade__enum__pb2.DESCRIPTOR,])




_QUERYORDERREQ = _descriptor.Descriptor(
  name='QueryOrderReq',
  full_name='trade.stock.QueryOrderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryOrderReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.QueryOrderReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryOrderReq.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_time', full_name='trade.stock.QueryOrderReq.begin_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='trade.stock.QueryOrderReq.end_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryOrderReq.investor_key', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=193,
)


_QUERYREPORTREQ = _descriptor.Descriptor(
  name='QueryReportReq',
  full_name='trade.stock.QueryReportReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryReportReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.QueryReportReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_no', full_name='trade.stock.QueryReportReq.trade_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryReportReq.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_time', full_name='trade.stock.QueryReportReq.begin_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='trade.stock.QueryReportReq.end_time', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryReportReq.investor_key', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=343,
)


_QUERYASSETREQ = _descriptor.Descriptor(
  name='QueryAssetReq',
  full_name='trade.stock.QueryAssetReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryAssetReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryAssetReq.investor_key', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=401,
)


_QUERYASSETRSP = _descriptor.Descriptor(
  name='QueryAssetRsp',
  full_name='trade.stock.QueryAssetRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryAssetRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='trade.stock.QueryAssetRsp.currency', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_amount', full_name='trade.stock.QueryAssetRsp.begin_amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='trade.stock.QueryAssetRsp.deposit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdraw', full_name='trade.stock.QueryAssetRsp.withdraw', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_amount', full_name='trade.stock.QueryAssetRsp.current_amount', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_amount', full_name='trade.stock.QueryAssetRsp.total_amount', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='available', full_name='trade.stock.QueryAssetRsp.available', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawable', full_name='trade.stock.QueryAssetRsp.withdrawable', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_buy_amount', full_name='trade.stock.QueryAssetRsp.total_buy_amount', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_buy_fee', full_name='trade.stock.QueryAssetRsp.total_buy_fee', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_sell_amount', full_name='trade.stock.QueryAssetRsp.total_sell_amount', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_sell_fee', full_name='trade.stock.QueryAssetRsp.total_sell_fee', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_margin', full_name='trade.stock.QueryAssetRsp.frozen_margin', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='captial_asset', full_name='trade.stock.QueryAssetRsp.captial_asset', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_asset', full_name='trade.stock.QueryAssetRsp.security_asset', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit', full_name='trade.stock.QueryAssetRsp.close_profit', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commission', full_name='trade.stock.QueryAssetRsp.commission', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit', full_name='trade.stock.QueryAssetRsp.position_profit', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_profit', full_name='trade.stock.QueryAssetRsp.float_profit', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_transit', full_name='trade.stock.QueryAssetRsp.in_transit', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryAssetRsp.investor_key', index=21,
      number=22, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=926,
)


_QUERYPOSITIONREQ = _descriptor.Descriptor(
  name='QueryPositionReq',
  full_name='trade.stock.QueryPositionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryPositionReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryPositionReq.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryPositionReq.investor_key', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=928,
  serialized_end=1003,
)


_QUERYPOSITIONRSP = _descriptor.Descriptor(
  name='QueryPositionRsp',
  full_name='trade.stock.QueryPositionRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.QueryPositionRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stock_holder', full_name='trade.stock.QueryPositionRsp.stock_holder', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.QueryPositionRsp.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_name', full_name='trade.stock.QueryPositionRsp.symbol_name', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.QueryPositionRsp.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_begin', full_name='trade.stock.QueryPositionRsp.quantity_begin', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_begin_frozen', full_name='trade.stock.QueryPositionRsp.quantity_begin_frozen', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_buy_today', full_name='trade.stock.QueryPositionRsp.quantity_buy_today', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_buy_frozen_today', full_name='trade.stock.QueryPositionRsp.quantity_buy_frozen_today', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_sell_today', full_name='trade.stock.QueryPositionRsp.quantity_sell_today', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_sell_frozen_today', full_name='trade.stock.QueryPositionRsp.quantity_sell_frozen_today', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_available', full_name='trade.stock.QueryPositionRsp.quantity_available', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_current', full_name='trade.stock.QueryPositionRsp.quantity_current', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_price', full_name='trade.stock.QueryPositionRsp.last_price', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_price', full_name='trade.stock.QueryPositionRsp.cost_price', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_profit', full_name='trade.stock.QueryPositionRsp.float_profit', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.QueryPositionRsp.investor_key', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1466,
)


_ORDERINSERTREQ = _descriptor.Descriptor(
  name='OrderInsertReq',
  full_name='trade.stock.OrderInsertReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderInsertReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderInsertReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.OrderInsertReq.local_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.OrderInsertReq.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderInsertReq.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.OrderInsertReq.price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.OrderInsertReq.quantity', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_type', full_name='trade.stock.OrderInsertReq.price_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.OrderInsertReq.action', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.OrderInsertReq.business_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_source', full_name='trade.stock.OrderInsertReq.order_source', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.stock.OrderInsertReq.order_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderInsertReq.investor_key', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_id', full_name='trade.stock.OrderInsertReq.instruction_id', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portfolio_id', full_name='trade.stock.OrderInsertReq.portfolio_id', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combi_no', full_name='trade.stock.OrderInsertReq.combi_no', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.OrderInsertReq.user_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_deal_flag', full_name='trade.stock.OrderInsertReq.order_deal_flag', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='institution_id', full_name='trade.stock.OrderInsertReq.institution_id', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1469,
  serialized_end=1983,
)


_ORDERINSERTRSP = _descriptor.Descriptor(
  name='OrderInsertRsp',
  full_name='trade.stock.OrderInsertRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderInsertRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderInsertRsp.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.OrderInsertRsp.local_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.OrderInsertRsp.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderInsertRsp.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.OrderInsertRsp.price', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.OrderInsertRsp.quantity', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_type', full_name='trade.stock.OrderInsertRsp.price_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.OrderInsertRsp.action', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.OrderInsertRsp.business_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_source', full_name='trade.stock.OrderInsertRsp.order_source', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.stock.OrderInsertRsp.order_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderInsertRsp.code', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderInsertRsp.message', index=13,
      number=14, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderInsertRsp.investor_key', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_id', full_name='trade.stock.OrderInsertRsp.instruction_id', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portfolio_id', full_name='trade.stock.OrderInsertRsp.portfolio_id', index=16,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combi_no', full_name='trade.stock.OrderInsertRsp.combi_no', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.OrderInsertRsp.user_id', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2482,
)


_ORDERCANCELREQ = _descriptor.Descriptor(
  name='OrderCancelReq',
  full_name='trade.stock.OrderCancelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderCancelReq.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderCancelReq.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_cancel_order_no', full_name='trade.stock.OrderCancelReq.local_cancel_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.stock.OrderCancelReq.cancel_order_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderCancelReq.investor_key', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderCancelReq.exchange', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2485,
  serialized_end=2659,
)


_ORDERCANCELRSP = _descriptor.Descriptor(
  name='OrderCancelRsp',
  full_name='trade.stock.OrderCancelRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderCancelRsp.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderCancelRsp.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.stock.OrderCancelRsp.cancel_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_cancel_order_no', full_name='trade.stock.OrderCancelRsp.local_cancel_order_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderCancelRsp.message', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderCancelRsp.code', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderCancelRsp.investor_key', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2824,
)


_ORDERCANCELFAILINFO = _descriptor.Descriptor(
  name='OrderCancelFailInfo',
  full_name='trade.stock.OrderCancelFailInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='trade.stock.OrderCancelFailInfo.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderCancelFailInfo.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderCancelFailInfo.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2826,
  serialized_end=2922,
)


_ORDERINFO = _descriptor.Descriptor(
  name='OrderInfo',
  full_name='trade.stock.OrderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.OrderInfo.order_no', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.OrderInfo.local_order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_cancel_order_no', full_name='trade.stock.OrderInfo.local_cancel_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.stock.OrderInfo.cancel_order_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.OrderInfo.symbol', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.OrderInfo.exchange', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.OrderInfo.price', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.OrderInfo.quantity', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_type', full_name='trade.stock.OrderInfo.price_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.OrderInfo.action', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.OrderInfo.business_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_traded', full_name='trade.stock.OrderInfo.quantity_traded', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_left', full_name='trade.stock.OrderInfo.quantity_left', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_time', full_name='trade.stock.OrderInfo.insert_time', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='trade.stock.OrderInfo.update_time', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_time', full_name='trade.stock.OrderInfo.cancel_time', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_margin', full_name='trade.stock.OrderInfo.frozen_margin', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.stock.OrderInfo.trade_amount', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_status', full_name='trade.stock.OrderInfo.order_status', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.stock.OrderInfo.order_type', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.OrderInfo.client_id', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.stock.OrderInfo.code', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.stock.OrderInfo.message', index=22,
      number=23, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.OrderInfo.investor_key', index=23,
      number=24, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_price', full_name='trade.stock.OrderInfo.avg_price', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_name', full_name='trade.stock.OrderInfo.symbol_name', index=25,
      number=26, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_id', full_name='trade.stock.OrderInfo.instruction_id', index=26,
      number=27, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portfolio_id', full_name='trade.stock.OrderInfo.portfolio_id', index=27,
      number=28, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combi_no', full_name='trade.stock.OrderInfo.combi_no', index=28,
      number=29, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.OrderInfo.user_id', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_trade_time', full_name='trade.stock.OrderInfo.first_trade_time', index=30,
      number=31, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity_canceled', full_name='trade.stock.OrderInfo.quantity_canceled', index=31,
      number=32, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='institution_id', full_name='trade.stock.OrderInfo.institution_id', index=32,
      number=33, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='trade.stock.OrderInfo.seq_no', index=33,
      number=34, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_deal_flag', full_name='trade.stock.OrderInfo.order_deal_flag', index=34,
      number=35, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2925,
  serialized_end=3814,
)


_TRADEREPORTINFO = _descriptor.Descriptor(
  name='TradeReportInfo',
  full_name='trade.stock.TradeReportInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.stock.TradeReportInfo.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.stock.TradeReportInfo.order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.stock.TradeReportInfo.local_order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.stock.TradeReportInfo.symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.stock.TradeReportInfo.exchange', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_no', full_name='trade.stock.TradeReportInfo.trade_no', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.stock.TradeReportInfo.price', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='trade.stock.TradeReportInfo.quantity', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.stock.TradeReportInfo.trade_time', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.stock.TradeReportInfo.trade_amount', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_index', full_name='trade.stock.TradeReportInfo.report_index', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_type', full_name='trade.stock.TradeReportInfo.trade_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='trade.stock.TradeReportInfo.action', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_type', full_name='trade.stock.TradeReportInfo.business_type', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.stock.TradeReportInfo.investor_key', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_name', full_name='trade.stock.TradeReportInfo.symbol_name', index=15,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.stock.TradeReportInfo.user_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='trade.stock.TradeReportInfo.seq_no', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3817,
  serialized_end=4274,
)

_QUERYASSETRSP.fields_by_name['currency'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYPOSITIONRSP.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINSERTREQ.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINSERTREQ.fields_by_name['price_type'].enum_type = trade_dot_trade__enum__pb2._PRICETYPE
_ORDERINSERTREQ.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINSERTREQ.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
_ORDERINSERTREQ.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_ORDERINSERTRSP.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINSERTRSP.fields_by_name['price_type'].enum_type = trade_dot_trade__enum__pb2._PRICETYPE
_ORDERINSERTRSP.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINSERTRSP.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
_ORDERINSERTRSP.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_ORDERCANCELREQ.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERCANCELFAILINFO.fields_by_name['order'].message_type = _ORDERCANCELREQ
_ORDERINFO.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_ORDERINFO.fields_by_name['price_type'].enum_type = trade_dot_trade__enum__pb2._PRICETYPE
_ORDERINFO.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINFO.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
_ORDERINFO.fields_by_name['order_status'].enum_type = trade_dot_trade__enum__pb2._ORDERSTATUSTYPE
_ORDERINFO.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_TRADEREPORTINFO.fields_by_name['exchange'].enum_type = trade_dot_trade__enum__pb2._EXCHANGETYPE
_TRADEREPORTINFO.fields_by_name['trade_type'].enum_type = trade_dot_trade__enum__pb2._TRADETYPE
_TRADEREPORTINFO.fields_by_name['action'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_TRADEREPORTINFO.fields_by_name['business_type'].enum_type = trade_dot_trade__enum__pb2._BUSINESSTYPE
DESCRIPTOR.message_types_by_name['QueryOrderReq'] = _QUERYORDERREQ
DESCRIPTOR.message_types_by_name['QueryReportReq'] = _QUERYREPORTREQ
DESCRIPTOR.message_types_by_name['QueryAssetReq'] = _QUERYASSETREQ
DESCRIPTOR.message_types_by_name['QueryAssetRsp'] = _QUERYASSETRSP
DESCRIPTOR.message_types_by_name['QueryPositionReq'] = _QUERYPOSITIONREQ
DESCRIPTOR.message_types_by_name['QueryPositionRsp'] = _QUERYPOSITIONRSP
DESCRIPTOR.message_types_by_name['OrderInsertReq'] = _ORDERINSERTREQ
DESCRIPTOR.message_types_by_name['OrderInsertRsp'] = _ORDERINSERTRSP
DESCRIPTOR.message_types_by_name['OrderCancelReq'] = _ORDERCANCELREQ
DESCRIPTOR.message_types_by_name['OrderCancelRsp'] = _ORDERCANCELRSP
DESCRIPTOR.message_types_by_name['OrderCancelFailInfo'] = _ORDERCANCELFAILINFO
DESCRIPTOR.message_types_by_name['OrderInfo'] = _ORDERINFO
DESCRIPTOR.message_types_by_name['TradeReportInfo'] = _TRADEREPORTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryOrderReq = _reflection.GeneratedProtocolMessageType('QueryOrderReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORDERREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryOrderReq)
  })
_sym_db.RegisterMessage(QueryOrderReq)

QueryReportReq = _reflection.GeneratedProtocolMessageType('QueryReportReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryReportReq)
  })
_sym_db.RegisterMessage(QueryReportReq)

QueryAssetReq = _reflection.GeneratedProtocolMessageType('QueryAssetReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYASSETREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryAssetReq)
  })
_sym_db.RegisterMessage(QueryAssetReq)

QueryAssetRsp = _reflection.GeneratedProtocolMessageType('QueryAssetRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYASSETRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryAssetRsp)
  })
_sym_db.RegisterMessage(QueryAssetRsp)

QueryPositionReq = _reflection.GeneratedProtocolMessageType('QueryPositionReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryPositionReq)
  })
_sym_db.RegisterMessage(QueryPositionReq)

QueryPositionRsp = _reflection.GeneratedProtocolMessageType('QueryPositionRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.QueryPositionRsp)
  })
_sym_db.RegisterMessage(QueryPositionRsp)

OrderInsertReq = _reflection.GeneratedProtocolMessageType('OrderInsertReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINSERTREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderInsertReq)
  })
_sym_db.RegisterMessage(OrderInsertReq)

OrderInsertRsp = _reflection.GeneratedProtocolMessageType('OrderInsertRsp', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINSERTRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderInsertRsp)
  })
_sym_db.RegisterMessage(OrderInsertRsp)

OrderCancelReq = _reflection.GeneratedProtocolMessageType('OrderCancelReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELREQ,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderCancelReq)
  })
_sym_db.RegisterMessage(OrderCancelReq)

OrderCancelRsp = _reflection.GeneratedProtocolMessageType('OrderCancelRsp', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELRSP,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderCancelRsp)
  })
_sym_db.RegisterMessage(OrderCancelRsp)

OrderCancelFailInfo = _reflection.GeneratedProtocolMessageType('OrderCancelFailInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELFAILINFO,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderCancelFailInfo)
  })
_sym_db.RegisterMessage(OrderCancelFailInfo)

OrderInfo = _reflection.GeneratedProtocolMessageType('OrderInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINFO,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.OrderInfo)
  })
_sym_db.RegisterMessage(OrderInfo)

TradeReportInfo = _reflection.GeneratedProtocolMessageType('TradeReportInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRADEREPORTINFO,
  '__module__' : 'trade.trade_stock_pb2'
  # @@protoc_insertion_point(class_scope:trade.stock.TradeReportInfo)
  })
_sym_db.RegisterMessage(TradeReportInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
