# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trade/trade_futures.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from trade import trade_enum_pb2 as trade_dot_trade__enum__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='trade/trade_futures.proto',
  package='trade.futures',
  syntax='proto3',
  serialized_options=_b('\242\002\003TFT'),
  serialized_pb=_b('\n\x19trade/trade_futures.proto\x12\rtrade.futures\x1a\x16trade/trade_enum.proto\"Y\n\x15UserPasswordUpdateReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x14\n\x0cold_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\"\x8b\x02\n\x15UserPasswordUpdateRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x14\n\x0cold_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\x12\x11\n\tbroker_id\x18\x04 \x01(\t\x12\x13\n\x0binvestor_id\x18\x05 \x01(\t\x12\x10\n\x08\x65rror_id\x18\x06 \x01(\x05\x12\x11\n\terror_msg\x18\x07 \x01(\x0c\x12\x30\n\x0cspecial_flag\x18\x08 \x01(\x0e\x32\x1a.trade.tag.SpecialFlagType\x12\x0c\n\x04\x63ode\x18\t \x01(\x05\x12\x0f\n\x07message\x18\n \x01(\x0c\x12\x12\n\nvoucher_no\x18\x0b \x01(\t\"P\n\x10QueryInvestorReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\"\xd8\x02\n\x10QueryInvestorRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x19\n\x11investor_group_id\x18\x04 \x01(\t\x12\x13\n\x0b\x63lient_name\x18\x05 \x01(\x0c\x12\x11\n\tis_active\x18\x06 \x01(\x08\x12\x11\n\ttelephone\x18\x07 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x08 \x01(\x0c\x12\x11\n\topen_date\x18\t \x01(\t\x12\x0e\n\x06mobile\x18\n \x01(\t\x12\x15\n\rcomm_model_id\x18\x0b \x01(\t\x12\x17\n\x0fmargin_model_id\x18\x0c \x01(\t\x12\x1b\n\x13identifiedi_card_no\x18\r \x01(\t\x12/\n\x0cid_card_type\x18\x0e \x01(\x0e\x32\x19.trade.tag.IdCardTypeType\"\xaf\x01\n\x18\x43onfirmSettlementInfoReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x13\n\x0btrading_day\x18\x04 \x01(\t\x12\x12\n\naccount_id\x18\x05 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\"\xf0\x01\n\x18\x43onfirmSettlementInfoRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirm_date\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirm_time\x18\x05 \x01(\t\x12\x15\n\rsettlement_id\x18\x06 \x01(\x05\x12\x12\n\naccount_id\x18\x07 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x08 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x11\n\tbill_flag\x18\t \x01(\x08\"\xd3\x01\n\x16QuerySettlementInfoReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x13\n\x0btrading_day\x18\x04 \x01(\t\x12\x12\n\naccount_id\x18\x05 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x12\n\nstart_date\x18\x07 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x08 \x01(\t\"\x93\x02\n\x16QuerySettlementInfoRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x13\n\x0btrading_day\x18\x04 \x01(\t\x12\x15\n\rsettlement_id\x18\x05 \x01(\x05\x12\x13\n\x0bsequence_no\x18\x06 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\x0c\x12\x12\n\naccount_id\x18\x08 \x01(\t\x12,\n\x0b\x63urrency_id\x18\t \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x11\n\tbill_flag\x18\n \x01(\x08\x12\x14\n\x0c\x63ontent_size\x18\x0b \x01(\x04\"\x9f\x01\n\x1dQuerySettlementInfoConfirmReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x05 \x01(\x0e\x32\x17.trade.tag.CurrencyType\"\xe2\x01\n\x1dQuerySettlementInfoConfirmRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirm_date\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirm_time\x18\x05 \x01(\t\x12\x15\n\rsettlement_id\x18\x06 \x01(\x05\x12\x12\n\naccount_id\x18\x07 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x08 \x01(\x0e\x32\x17.trade.tag.CurrencyType\"\xae\x01\n\rQueryOrderReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12\x14\n\x0corder_sys_id\x18\x04 \x01(\t\x12\x19\n\x11insert_time_start\x18\x05 \x01(\t\x12\x17\n\x0finsert_time_end\x18\x06 \x01(\t\x12\x11\n\tclient_id\x18\x07 \x01(\t\"\xd5\x01\n\x0eQueryReportReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12\x10\n\x08trade_id\x18\x04 \x01(\t\x12\x18\n\x10trade_time_start\x18\x05 \x01(\t\x12\x16\n\x0etrade_time_end\x18\x06 \x01(\t\x12\x11\n\tclient_id\x18\x07 \x01(\t\x12*\n\x06status\x18\x08 \x01(\x0e\x32\x1a.trade.tag.TradeStatusType\"\xb5\x01\n\rQueryAssetReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12,\n\x0b\x63urrency_id\x18\x02 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12$\n\x08\x62iz_type\x18\x03 \x01(\x0e\x32\x12.trade.tag.BizType\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\x11\n\tclient_id\x18\x05 \x01(\t\x12\x13\n\x0btrading_day\x18\x06 \x01(\t\"\xcc\n\n\rQueryAssetRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x14\n\x0cpre_mortgage\x18\x02 \x01(\x01\x12\x12\n\npre_credit\x18\x03 \x01(\x01\x12\x13\n\x0bpre_deposit\x18\x04 \x01(\x01\x12\x13\n\x0bpre_balance\x18\x05 \x01(\x01\x12\x12\n\npre_margin\x18\x06 \x01(\x01\x12\x15\n\rinterest_base\x18\x07 \x01(\x01\x12\x10\n\x08interest\x18\x08 \x01(\x01\x12\x0f\n\x07\x64\x65posit\x18\t \x01(\x01\x12\x10\n\x08withdraw\x18\n \x01(\x01\x12\x15\n\rfrozen_margin\x18\x0b \x01(\x01\x12\x13\n\x0b\x66rozen_cash\x18\x0c \x01(\x01\x12\x19\n\x11\x66rozen_commission\x18\r \x01(\x01\x12\x13\n\x0b\x63urr_margin\x18\x0e \x01(\x01\x12\x0f\n\x07\x63\x61sh_in\x18\x0f \x01(\x01\x12\x12\n\ncommission\x18\x10 \x01(\x01\x12\x14\n\x0c\x63lose_profit\x18\x11 \x01(\x01\x12\x17\n\x0fposition_profit\x18\x12 \x01(\x01\x12\x0f\n\x07\x62\x61lance\x18\x13 \x01(\x01\x12\x11\n\tavailable\x18\x14 \x01(\x01\x12\x16\n\x0ewithdraw_quota\x18\x15 \x01(\x01\x12\x0f\n\x07reserve\x18\x16 \x01(\x01\x12\x13\n\x0btrading_day\x18\x17 \x01(\t\x12\x15\n\rsettlement_id\x18\x18 \x01(\x05\x12\x0e\n\x06\x63redit\x18\x19 \x01(\x01\x12\x10\n\x08mortgage\x18\x1a \x01(\x01\x12\x17\n\x0f\x65xchange_margin\x18\x1b \x01(\x01\x12\x17\n\x0f\x64\x65livery_margin\x18\x1c \x01(\x01\x12 \n\x18\x65xchange_delivery_margin\x18\x1d \x01(\x01\x12\x17\n\x0freserve_balance\x18\x1e \x01(\x01\x12,\n\x0b\x63urrency_id\x18\x1f \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x1c\n\x14pre_fund_mortgage_in\x18  \x01(\x01\x12\x1d\n\x15pre_fund_mortgage_out\x18! \x01(\x01\x12\x18\n\x10\x66und_mortgage_in\x18\" \x01(\x01\x12\x19\n\x11\x66und_mortgage_out\x18# \x01(\x01\x12\x1f\n\x17\x66und_mortgage_available\x18$ \x01(\x01\x12\x19\n\x11mortgageable_fund\x18% \x01(\x01\x12\x1b\n\x13spec_product_margin\x18& \x01(\x01\x12\"\n\x1aspec_product_frozen_margin\x18\' \x01(\x01\x12\x1f\n\x17spec_product_commission\x18( \x01(\x01\x12&\n\x1espec_product_frozen_commission\x18) \x01(\x01\x12$\n\x1cspec_product_position_profit\x18* \x01(\x01\x12!\n\x19spec_product_close_profit\x18+ \x01(\x01\x12+\n#spec_product_position_profit_by_alg\x18, \x01(\x01\x12$\n\x1cspec_product_exchange_margin\x18- \x01(\x01\x12$\n\x08\x62iz_type\x18. \x01(\x0e\x32\x12.trade.tag.BizType\x12\x13\n\x0b\x66rozen_swap\x18/ \x01(\x01\x12\x13\n\x0bremain_swap\x18\x30 \x01(\x01\x12\x13\n\x0binvestor_id\x18\x31 \x01(\t\x12\x11\n\tclient_id\x18\x32 \x01(\t\x12\x1d\n\x15\x63lose_profit_by_trade\x18\x33 \x01(\x01\x12 \n\x18position_profit_by_trade\x18\x34 \x01(\x01\"\x80\x01\n\x10QueryPositionReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12\x17\n\x0fhistorical_date\x18\x04 \x01(\t\x12\x11\n\tclient_id\x18\x05 \x01(\t\"\xc3\n\n\x10QueryPositionRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x34\n\x0eposi_direction\x18\x03 \x01(\x0e\x32\x1c.trade.tag.PosiDirectionType\x12,\n\nhedge_flag\x18\x04 \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12\x15\n\rposition_date\x18\x05 \x01(\x05\x12\x13\n\x0byd_position\x18\x06 \x01(\x05\x12\x10\n\x08position\x18\x07 \x01(\x05\x12\x13\n\x0blong_frozen\x18\x08 \x01(\x05\x12\x14\n\x0cshort_frozen\x18\t \x01(\x05\x12\x1a\n\x12long_frozen_amount\x18\n \x01(\x01\x12\x1b\n\x13short_frozen_amount\x18\x0b \x01(\x01\x12\x13\n\x0bopen_volume\x18\x0c \x01(\x05\x12\x14\n\x0c\x63lose_volume\x18\r \x01(\x05\x12\x13\n\x0bopen_amount\x18\x0e \x01(\x01\x12\x14\n\x0c\x63lose_amount\x18\x0f \x01(\x01\x12\x15\n\rposition_cost\x18\x10 \x01(\x01\x12\x12\n\npre_margin\x18\x11 \x01(\x01\x12\x12\n\nuse_margin\x18\x12 \x01(\x01\x12\x15\n\rfrozen_margin\x18\x13 \x01(\x01\x12\x13\n\x0b\x66rozen_cash\x18\x14 \x01(\x01\x12\x19\n\x11\x66rozen_commission\x18\x15 \x01(\x01\x12\x0f\n\x07\x63\x61sh_in\x18\x16 \x01(\x01\x12\x12\n\ncommission\x18\x17 \x01(\x01\x12\x14\n\x0c\x63lose_profit\x18\x18 \x01(\x01\x12\x17\n\x0fposition_profit\x18\x19 \x01(\x01\x12\x1c\n\x14pre_settlement_price\x18\x1a \x01(\x01\x12\x18\n\x10settlement_price\x18\x1b \x01(\x01\x12\x13\n\x0btrading_day\x18\x1c \x01(\t\x12\x15\n\rsettlement_id\x18\x1d \x01(\x05\x12\x11\n\topen_cost\x18\x1e \x01(\x01\x12\x17\n\x0f\x65xchange_margin\x18\x1f \x01(\x01\x12\x15\n\rcomb_position\x18  \x01(\x05\x12\x18\n\x10\x63omb_long_frozen\x18! \x01(\x05\x12\x19\n\x11\x63omb_short_frozen\x18\" \x01(\x05\x12\x1c\n\x14\x63lose_profit_by_date\x18# \x01(\x01\x12\x1d\n\x15\x63lose_profit_by_trade\x18$ \x01(\x01\x12\x16\n\x0etoday_position\x18% \x01(\x05\x12\x1c\n\x14margin_rate_by_money\x18& \x01(\x01\x12\x1d\n\x15margin_rate_by_volume\x18\' \x01(\x01\x12\x15\n\rstrike_frozen\x18( \x01(\x05\x12\x1c\n\x14strike_frozen_amount\x18) \x01(\x01\x12\x16\n\x0e\x61\x62\x61ndon_frozen\x18* \x01(\x05\x12\x13\n\x0b\x65xchange_id\x18+ \x01(\t\x12\x18\n\x10yd_strike_frozen\x18, \x01(\x05\x12\x13\n\x0binvestor_id\x18- \x01(\t\x12\x11\n\tclient_id\x18. \x01(\t\x12\x17\n\x0f\x65nable_position\x18/ \x01(\x05\x12\x14\n\x0ctas_position\x18\x30 \x01(\x05\x12\x19\n\x11tas_position_cost\x18\x31 \x01(\x01\x12\x1a\n\x12td_enable_position\x18\x32 \x01(\x05\x12\x1a\n\x12yd_enable_position\x18\x33 \x01(\x05\x12\x19\n\x11\x61verage_open_cost\x18\x34 \x01(\x01\x12\x1d\n\x15\x61verage_position_cost\x18\x35 \x01(\x01\"\x97\x01\n\x16QueryPositionDetailReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12\x17\n\x0fhistorical_date\x18\x04 \x01(\t\x12\"\n\x04type\x18\x05 \x01(\x0e\x32\x14.trade.tag.QueryType\"\x9e\x06\n\x16QueryPositionDetailRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12,\n\nhedge_type\x18\x03 \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12(\n\tdirection\x18\x04 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x11\n\topen_date\x18\x05 \x01(\t\x12\x10\n\x08trade_id\x18\x06 \x01(\t\x12\x0e\n\x06volume\x18\x07 \x01(\x05\x12\x12\n\nopen_price\x18\x08 \x01(\x01\x12\x13\n\x0btrading_day\x18\t \x01(\t\x12\x15\n\rsettlement_id\x18\n \x01(\x05\x12,\n\ntrade_type\x18\x0b \x01(\x0e\x32\x18.trade.tag.TradeTypeType\x12\x1a\n\x12\x63omb_instrument_id\x18\x0c \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\r \x01(\t\x12\x1c\n\x14\x63lose_profit_by_date\x18\x0e \x01(\x01\x12\x1d\n\x15\x63lose_profit_by_trade\x18\x0f \x01(\x01\x12\x1f\n\x17position_profit_by_date\x18\x10 \x01(\x01\x12 \n\x18position_profit_by_trade\x18\x11 \x01(\x01\x12\x0e\n\x06margin\x18\x12 \x01(\x01\x12\x13\n\x0b\x65xch_margin\x18\x13 \x01(\x01\x12\x1c\n\x14margin_rate_by_money\x18\x14 \x01(\x01\x12\x1d\n\x15margin_rate_by_volume\x18\x15 \x01(\x01\x12\x1d\n\x15last_settlement_price\x18\x16 \x01(\x01\x12\x18\n\x10settlement_price\x18\x17 \x01(\x01\x12\x14\n\x0c\x63lose_volume\x18\x18 \x01(\x05\x12\x14\n\x0c\x63lose_amount\x18\x19 \x01(\x01\x12\x13\n\x0binvestor_id\x18\x1a \x01(\t\x12\x37\n\x12position_date_type\x18\x1b \x01(\x0e\x32\x1b.trade.tag.PositionDateType\x12\x16\n\x0espec_posi_type\x18\x1c \x01(\x05\"Z\n\x16QueryCommissionRateReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\"\xee\x02\n\x16QueryCommissionRateRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x16\n\x0einvestor_range\x18\x03 \x01(\x05\x12\x1b\n\x13open_ratio_by_money\x18\x04 \x01(\x01\x12\x1c\n\x14open_ratio_by_volume\x18\x05 \x01(\x01\x12\x1c\n\x14\x63lose_ratio_by_money\x18\x06 \x01(\x01\x12\x1d\n\x15\x63lose_ratio_by_volume\x18\x07 \x01(\x01\x12\"\n\x1a\x63lose_today_ratio_by_money\x18\x08 \x01(\x01\x12#\n\x1b\x63lose_today_ratio_by_volume\x18\t \x01(\x01\x12\x13\n\x0b\x65xchange_id\x18\n \x01(\t\x12$\n\x08\x62iz_type\x18\x0b \x01(\x0e\x32\x12.trade.tag.BizType\x12\x13\n\x0binvestor_id\x18\x0c \x01(\t\"\x84\x01\n\x12QueryMarginRateReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12,\n\nhedge_flag\x18\x03 \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12\x13\n\x0b\x65xchange_id\x18\x04 \x01(\t\"\xda\x02\n\x12QueryMarginRateRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x16\n\x0einvestor_range\x18\x03 \x01(\x05\x12,\n\nhedge_flag\x18\x04 \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12\"\n\x1along_margin_ratio_by_money\x18\x05 \x01(\x01\x12#\n\x1blong_margin_ratio_by_volume\x18\x06 \x01(\x01\x12#\n\x1bshort_margin_ratio_by_money\x18\x07 \x01(\x01\x12$\n\x1cshort_margin_ratio_by_volume\x18\x08 \x01(\x01\x12\x13\n\x0bis_relative\x18\t \x01(\x08\x12\x13\n\x0b\x65xchange_id\x18\n \x01(\t\x12\x13\n\x0binvestor_id\x18\x0b \x01(\t\"\xef\x06\n\x0eOrderInsertReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x10\n\x08order_no\x18\x03 \x01(\t\x12\x33\n\x10order_price_type\x18\x04 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12(\n\tdirection\x18\x05 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x06 \x01(\t\x12\x17\n\x0f\x63omb_hedge_flag\x18\x07 \x01(\t\x12\x13\n\x0blimit_price\x18\x08 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\t \x01(\x05\x12\x34\n\x0etime_condition\x18\n \x01(\x0e\x32\x1c.trade.tag.TimeConditionType\x12\x10\n\x08gtd_date\x18\x0b \x01(\t\x12\x38\n\x10volume_condition\x18\x0c \x01(\x0e\x32\x1e.trade.tag.VolumeConditionType\x12\x12\n\nmin_volume\x18\r \x01(\x05\x12@\n\x14\x63ontingent_condition\x18\x0e \x01(\x0e\x32\".trade.tag.ContingentConditionType\x12\x12\n\nstop_price\x18\x0f \x01(\x01\x12;\n\x12\x66orce_close_reason\x18\x10 \x01(\x0e\x32\x1f.trade.tag.ForceCloseReasonType\x12\x18\n\x10user_force_close\x18\x12 \x01(\x08\x12\x15\n\ris_swap_order\x18\x13 \x01(\x08\x12\x13\n\x0b\x65xchange_id\x18\x14 \x01(\t\x12\x16\n\x0elocal_order_no\x18\x15 \x01(\t\x12\x11\n\tclient_id\x18\x16 \x01(\t\x12%\n\x06source\x18\x17 \x01(\x0e\x32\x15.trade.tag.SourceType\x12\x14\n\x0cis_back_hand\x18\x18 \x01(\x08\x12\x17\n\x0fis_change_order\x18\x19 \x01(\x08\x12\x37\n\x14new_order_price_type\x18\x1a \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x17\n\x0fnew_limit_price\x18\x1b \x01(\x01\x12\x16\n\x0eprice_tick_num\x18\x1c \x01(\x05\"]\n\x0eOrderInsertRsp\x12,\n\x05order\x18\x01 \x01(\x0b\x32\x1d.trade.futures.OrderInsertReq\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"\xd5\x02\n\x0eOrderCancelReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x17\n\x0f\x63\x61ncel_order_no\x18\x02 \x01(\t\x12\x10\n\x08order_no\x18\x03 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x07 \x01(\t\x12\x14\n\x0corder_sys_id\x18\x08 \x01(\t\x12\x15\n\rinstrument_id\x18\t \x01(\t\x12\x13\n\x0binvestor_id\x18\n \x01(\t\x12\x11\n\tclient_id\x18\x0b \x01(\t\x12\x17\n\x0fis_change_order\x18\x0c \x01(\x08\x12\x1d\n\x15volume_total_original\x18\r \x01(\x05\x12\x33\n\x10order_price_type\x18\x0e \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x0f \x01(\x01\x12\x16\n\x0eprice_tick_num\x18\x10 \x01(\x05\"]\n\x0eOrderCancelRsp\x12,\n\x05order\x18\x01 \x01(\x0b\x32\x1d.trade.futures.OrderCancelReq\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"|\n\x13OrderCancelFailInfo\x12,\n\x05order\x18\x01 \x01(\x0b\x32\x1d.trade.futures.OrderCancelReq\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\x12\x18\n\x10\x63hange_order_msg\x18\x04 \x01(\x0c\"\xa0\x0c\n\tOrderInfo\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x10\n\x08order_no\x18\x03 \x01(\t\x12\x33\n\x10order_price_type\x18\x04 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12(\n\tdirection\x18\x05 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x06 \x01(\t\x12\x17\n\x0f\x63omb_hedge_flag\x18\x07 \x01(\t\x12\x13\n\x0blimit_price\x18\x08 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\t \x01(\x05\x12\x34\n\x0etime_condition\x18\n \x01(\x0e\x32\x1c.trade.tag.TimeConditionType\x12\x10\n\x08gtd_date\x18\x0b \x01(\t\x12\x38\n\x10volume_condition\x18\x0c \x01(\x0e\x32\x1e.trade.tag.VolumeConditionType\x12\x12\n\nmin_volume\x18\r \x01(\x05\x12\x12\n\nstop_price\x18\x0e \x01(\x01\x12;\n\x12\x66orce_close_reason\x18\x0f \x01(\x0e\x32\x1f.trade.tag.ForceCloseReasonType\x12\x12\n\nrequest_id\x18\x10 \x01(\x05\x12\x16\n\x0eorder_local_id\x18\x11 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x12 \x01(\t\x12\x1b\n\x13order_submit_status\x18\x13 \x01(\x05\x12\x13\n\x0btrading_day\x18\x14 \x01(\t\x12\x15\n\rsettlement_id\x18\x15 \x01(\x05\x12\x14\n\x0corder_sys_id\x18\x16 \x01(\t\x12\x30\n\x0corder_status\x18\x17 \x01(\x0e\x32\x1a.trade.tag.OrderStatusType\x12(\n\norder_type\x18\x18 \x01(\x0e\x32\x14.trade.tag.OrderType\x12\x15\n\rvolume_traded\x18\x19 \x01(\x05\x12\x14\n\x0cvolume_total\x18\x1a \x01(\x05\x12\x13\n\x0binsert_date\x18\x1b \x01(\t\x12\x13\n\x0binsert_time\x18\x1c \x01(\t\x12\x13\n\x0b\x61\x63tive_time\x18\x1d \x01(\t\x12\x14\n\x0csuspend_time\x18\x1e \x01(\t\x12\x13\n\x0bupdate_time\x18\x1f \x01(\t\x12\x13\n\x0b\x63\x61ncel_time\x18  \x01(\t\x12\x19\n\x11user_product_info\x18! \x01(\t\x12\x12\n\nstatus_msg\x18\" \x01(\x0c\x12\x18\n\x10user_force_close\x18# \x01(\x08\x12\x18\n\x10\x62roker_order_seq\x18$ \x01(\x05\x12\x1d\n\x15relative_order_sys_id\x18% \x01(\t\x12\x1f\n\x17zce_total_traded_volume\x18& \x01(\x05\x12\x15\n\ris_swap_order\x18\' \x01(\x08\x12,\n\x0b\x63urrency_id\x18( \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12@\n\x14\x63ontingent_condition\x18) \x01(\x0e\x32\".trade.tag.ContingentConditionType\x12\x0c\n\x04\x63ode\x18* \x01(\x05\x12\x0f\n\x07message\x18+ \x01(\t\x12\x13\n\x0binvestor_id\x18, \x01(\t\x12\x16\n\x0elocal_order_no\x18- \x01(\t\x12\x17\n\x0frevocation_mark\x18. \x01(\t\x12\x11\n\tclient_id\x18/ \x01(\t\x12\x19\n\x11\x62\x61\x63k_hand_message\x18\x30 \x01(\x0c\x12!\n\x19new_volume_total_original\x18\x31 \x01(\x05\x12\x17\n\x0fnew_limit_price\x18\x32 \x01(\x01\x12\x37\n\x14new_order_price_type\x18\x33 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x17\n\x0fis_change_order\x18\x34 \x01(\x08\x12\x1c\n\x14\x63hange_order_message\x18\x35 \x01(\x0c\x12\x16\n\x0eprice_tick_num\x18\x36 \x01(\x05\"\xaa\x06\n\x0fTradeReportInfo\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x04 \x01(\t\x12\x10\n\x08trade_id\x18\x05 \x01(\t\x12(\n\tdirection\x18\x06 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x14\n\x0corder_sys_id\x18\x07 \x01(\t\x12.\n\x0boffset_flag\x18\x08 \x01(\x0e\x32\x19.trade.tag.OffsetFlagType\x12,\n\nhedge_flag\x18\t \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12\r\n\x05price\x18\n \x01(\x01\x12\x0e\n\x06volume\x18\x0b \x01(\x05\x12\x12\n\ntrade_date\x18\x0c \x01(\t\x12\x12\n\ntrade_time\x18\r \x01(\t\x12,\n\ntrade_type\x18\x0e \x01(\x0e\x32\x18.trade.tag.TradeTypeType\x12\x30\n\x0cprice_source\x18\x0f \x01(\x0e\x32\x1a.trade.tag.PriceSourceType\x12\x13\n\x0btrading_day\x18\x10 \x01(\t\x12\x13\n\x0binvestor_id\x18\x11 \x01(\t\x12\x11\n\tclient_id\x18\x12 \x01(\t\x12\x12\n\ncommission\x18\x13 \x01(\x01\x12\x14\n\x0c\x63lose_profit\x18\x14 \x01(\x01\x12\x37\n\x14new_order_price_type\x18\x15 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x14\n\x0cis_back_hand\x18\x16 \x01(\x08\x12\x1d\n\x15volume_total_original\x18\x17 \x01(\x05\x12\x16\n\x0eprice_tick_num\x18\x36 \x01(\x05\x12\x17\n\x0fnew_limit_price\x18\x37 \x01(\x01\x12\x19\n\x11\x62\x61\x63k_hand_message\x18\x38 \x01(\x0c\x12\x1c\n\x14\x63hange_order_message\x18\x39 \x01(\x0c\x12\x18\n\x10settlement_price\x18: \x01(\x01\x12\x11\n\topen_date\x18; \x01(\t\x12\x12\n\nopen_price\x18< \x01(\x01\"\xda\x01\n\x19InstrumentTradeStatusInfo\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.trade.tag.InstrumentType\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12:\n\x11instrument_status\x18\x04 \x01(\x0e\x32\x1f.trade.tag.InstrumentStatusType\x12\x12\n\nenter_time\x18\x05 \x01(\t\x12\x18\n\x10local_enter_time\x18\x06 \x01(\t\",\n\x14QueryContractBankReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\"h\n\x14QueryContractBankRsp\x12\x0f\n\x07\x62\x61nk_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x02 \x01(\t\x12\x11\n\tbank_name\x18\x03 \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x04 \x01(\x04\"]\n\x17QueryAccountregisterReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12,\n\x0b\x63urrency_id\x18\x02 \x01(\x0e\x32\x17.trade.tag.CurrencyType\"\x8d\x04\n\x17QueryAccountregisterRsp\x12\x0f\n\x07\x62\x61nk_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x15\n\rcustomer_name\x18\x05 \x01(\x0c\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x10\n\x08reg_date\x18\x07 \x01(\t\x12\x10\n\x08out_date\x18\x08 \x01(\t\x12\x12\n\ntrade_date\x18\t \x01(\t\x12\x1b\n\x13identifiedi_card_no\x18\n \x01(\t\x12*\n\tcust_type\x18\x0b \x01(\x0e\x32\x17.trade.tag.CustTypeType\x12\x35\n\x0fopen_or_destroy\x18\x0c \x01(\x0e\x32\x1c.trade.tag.OpenOrDestroyType\x12/\n\x0cid_card_type\x18\r \x01(\x0e\x32\x19.trade.tag.IdCardTypeType\x12\x31\n\rbank_acc_type\x18\x0e \x01(\x0e\x32\x1a.trade.tag.BankAccTypeType\x12\x14\n\x0cinvestor_key\x18\x0f \x01(\x04\x12\x11\n\tbank_name\x18\x10 \x01(\x0c\x12\x18\n\x10\x62roker_branch_id\x18\x11 \x01(\t\"\x93\x01\n\x16QueryTransferSerialReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61nk_id\x18\x02 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x03 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x05 \x01(\t\"\xb5\x04\n\x16QueryTransferSerialRsp\x12\x0f\n\x07\x62\x61nk_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x14\n\x0ctrade_amount\x18\x05 \x01(\x01\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x12\n\ntrade_date\x18\x07 \x01(\t\x12\x13\n\x0btrading_day\x18\x08 \x01(\t\x12\x13\n\x0b\x62\x61nk_serial\x18\t \x01(\t\x12\x1b\n\x13identifiedi_card_no\x18\n \x01(\t\x12\x14\n\x0cplate_serial\x18\x0b \x01(\x05\x12\x15\n\rfuture_serial\x18\x0c \x01(\x05\x12\x10\n\x08\x63ust_fee\x18\r \x01(\x01\x12\x12\n\nbroker_fee\x18\x0e \x01(\x01\x12\x11\n\tbank_name\x18\x0f \x01(\x0c\x12/\n\x0cid_card_type\x18\x10 \x01(\x0e\x32\x19.trade.tag.IdCardTypeType\x12\x12\n\ntrade_time\x18\x11 \x01(\t\x12\x35\n\x12transfer_direction\x18\x12 \x01(\x0e\x32\x19.trade.tag.TransDirection\x12\x10\n\x08\x65rror_id\x18\x13 \x01(\x05\x12\x11\n\terror_msg\x18\x14 \x01(\x0c\x12\x0f\n\x07results\x18\x15 \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x16 \x01(\x04\"\xf1\x01\n\x18QueryBankAccountMoneyReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61nk_id\x18\x02 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x03 \x01(\t\x12\x15\n\rbank_password\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x18\n\x10\x62roker_branch_id\x18\x07 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x08 \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\t \x01(\t\"\x89\x05\n\x18QueryBankAccountMoneyRsp\x12\x0f\n\x07\x62\x61nk_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x05 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x12\n\ntrade_date\x18\x06 \x01(\t\x12\x13\n\x0btrading_day\x18\x07 \x01(\t\x12\x13\n\x0b\x62\x61nk_serial\x18\x08 \x01(\t\x12\x1b\n\x13identifiedi_card_no\x18\t \x01(\t\x12\x12\n\ntrade_code\x18\n \x01(\t\x12\x14\n\x0cplate_serial\x18\x0b \x01(\x05\x12\x15\n\rfuture_serial\x18\x0c \x01(\x05\x12\x17\n\x0f\x62\x61nk_use_amount\x18\r \x01(\x01\x12\x19\n\x11\x62\x61nk_fetch_amount\x18\x0e \x01(\x01\x12\x11\n\tbank_name\x18\x0f \x01(\x0c\x12\x12\n\ntrade_time\x18\x10 \x01(\t\x12/\n\x0cid_card_type\x18\x11 \x01(\x0e\x32\x19.trade.tag.IdCardTypeType\x12-\n\rbank_pwd_flag\x18\x12 \x01(\x0e\x32\x16.trade.tag.PwdFlagType\x12-\n\rsecu_pwd_flag\x18\x13 \x01(\x0e\x32\x16.trade.tag.PwdFlagType\x12\x10\n\x08\x65rror_id\x18\x14 \x01(\x05\x12\x11\n\terror_msg\x18\x15 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x19 \x01(\x05\x12\x0f\n\x07message\x18\x1a \x01(\x0c\x12\x0f\n\x07results\x18\x1b \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x1c \x01(\x04\"\x82\x02\n\x13\x46romBankToFutureReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61nk_id\x18\x02 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x03 \x01(\t\x12\x15\n\rbank_password\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12\x14\n\x0ctrade_amount\x18\x06 \x01(\x01\x12,\n\x0b\x63urrency_id\x18\x07 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x18\n\x10\x62roker_branch_id\x18\x08 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\t \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\n \x01(\t\"\xd8\x05\n\x13\x46romBankToFutureRsp\x12\x0f\n\x07\x62\x61nk_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x14\n\x0ctrade_amount\x18\x05 \x01(\x01\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x12\n\ntrade_date\x18\x07 \x01(\t\x12\x13\n\x0btrading_day\x18\x08 \x01(\t\x12\x1b\n\x13identifiedi_card_no\x18\t \x01(\t\x12\x13\n\x0b\x62\x61nk_serial\x18\n \x01(\t\x12\x14\n\x0cplate_serial\x18\x0b \x01(\x05\x12\x15\n\rfuture_serial\x18\x0c \x01(\x05\x12\x10\n\x08\x63ust_fee\x18\r \x01(\x01\x12\x12\n\nbroker_fee\x18\x0e \x01(\x01\x12\x1b\n\x13\x66uture_fetch_amount\x18\x0f \x01(\x01\x12.\n\x0ftransfer_status\x18\x10 \x01(\x0e\x32\x15.trade.tag.StatusType\x12-\n\rbank_pwd_flag\x18\x11 \x01(\x0e\x32\x16.trade.tag.PwdFlagType\x12-\n\rsecu_pwd_flag\x18\x12 \x01(\x0e\x32\x16.trade.tag.PwdFlagType\x12/\n\x0cid_card_type\x18\x13 \x01(\x0e\x32\x19.trade.tag.IdCardTypeType\x12\x35\n\x12transfer_direction\x18\x14 \x01(\x0e\x32\x19.trade.tag.TransDirection\x12\x12\n\ntrade_time\x18\x15 \x01(\t\x12\x10\n\x08\x65rror_id\x18\x16 \x01(\x05\x12\x11\n\terror_msg\x18\x17 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x18 \x01(\x05\x12\x0f\n\x07message\x18\x19 \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x1a \x01(\x04\"\xb9\x02\n\x13\x46romFutureToBankReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61nk_id\x18\x02 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x14\n\x0ctrade_amount\x18\x05 \x01(\x01\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x18\n\x10\x62roker_branch_id\x18\x07 \x01(\t\x12\x15\n\rbank_password\x18\x08 \x01(\t\x12\x35\n\x12transfer_direction\x18\t \x01(\x0e\x32\x19.trade.tag.TransDirection\x12\x0f\n\x07\x61\x63\x63ount\x18\n \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\x0b \x01(\t\"\xd8\x05\n\x13\x46romFutureToBankRsp\x12\x0f\n\x07\x62\x61nk_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61nk_branch_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62\x61nk_account\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x14\n\x0ctrade_amount\x18\x05 \x01(\x01\x12,\n\x0b\x63urrency_id\x18\x06 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x12\n\ntrade_date\x18\x07 \x01(\t\x12\x13\n\x0btrading_day\x18\x08 \x01(\t\x12\x1b\n\x13identifiedi_card_no\x18\t \x01(\t\x12\x13\n\x0b\x62\x61nk_serial\x18\n \x01(\t\x12\x14\n\x0cplate_serial\x18\x0b \x01(\x05\x12\x15\n\rfuture_serial\x18\x0c \x01(\x05\x12\x10\n\x08\x63ust_fee\x18\r \x01(\x01\x12\x12\n\nbroker_fee\x18\x0e \x01(\x01\x12\x1b\n\x13\x66uture_fetch_amount\x18\x0f \x01(\x01\x12.\n\x0ftransfer_status\x18\x10 \x01(\x0e\x32\x15.trade.tag.StatusType\x12-\n\rbank_pwd_flag\x18\x11 \x01(\x0e\x32\x16.trade.tag.PwdFlagType\x12-\n\rsecu_pwd_flag\x18\x12 \x01(\x0e\x32\x16.trade.tag.PwdFlagType\x12/\n\x0cid_card_type\x18\x13 \x01(\x0e\x32\x19.trade.tag.IdCardTypeType\x12\x35\n\x12transfer_direction\x18\x14 \x01(\x0e\x32\x19.trade.tag.TransDirection\x12\x12\n\ntrade_time\x18\x15 \x01(\t\x12\x10\n\x08\x65rror_id\x18\x16 \x01(\x05\x12\x11\n\terror_msg\x18\x17 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x18 \x01(\x05\x12\x0f\n\x07message\x18\x19 \x01(\x0c\x12\x14\n\x0cinvestor_key\x18\x1a \x01(\x04\"\x91\x01\n\x1fTradingAccountPasswordUpdateReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x14\n\x0cold_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x04 \x01(\x0e\x32\x17.trade.tag.CurrencyType\"\xaf\x02\n\x1fTradingAccountPasswordUpdateRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x14\n\x0cold_password\x18\x03 \x01(\t\x12\x14\n\x0cnew_password\x18\x04 \x01(\t\x12,\n\x0b\x63urrency_id\x18\x05 \x01(\x0e\x32\x17.trade.tag.CurrencyType\x12\x10\n\x08\x65rror_id\x18\x06 \x01(\x05\x12\x11\n\terror_msg\x18\x07 \x01(\x0c\x12\x30\n\x0cspecial_flag\x18\x08 \x01(\x0e\x32\x1a.trade.tag.SpecialFlagType\x12\x0c\n\x04\x63ode\x18\t \x01(\x05\x12\x0f\n\x07message\x18\n \x01(\x0c\x12\x12\n\nvoucher_no\x18\x0b \x01(\t\"\xb3\x01\n\x11QryTradingCodeReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08\x12\x33\n\x0e\x63lient_id_type\x18\x05 \x01(\x0e\x32\x1b.trade.tag.ClientIDTypeType\x12\x18\n\x10investor_unit_id\x18\x06 \x01(\t\"\x82\x02\n\x11QryTradingCodeRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x11\n\tis_active\x18\x05 \x01(\x08\x12$\n\x08\x62iz_type\x18\x06 \x01(\x0e\x32\x12.trade.tag.BizType\x12\x33\n\x0e\x63lient_id_type\x18\x07 \x01(\x0e\x32\x1b.trade.tag.ClientIDTypeType\x12\x18\n\x10investor_unit_id\x18\x08 \x01(\t\x12\x14\n\x0ctrading_code\x18\t \x01(\t\"\xa5\x02\n\x16QueryMaxOrderVolumeReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12(\n\tdirection\x18\x04 \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\x0boffset_flag\x18\x05 \x01(\x0e\x32\x19.trade.tag.OffsetFlagType\x12,\n\nhedge_flag\x18\x06 \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12\x12\n\nmax_volume\x18\x07 \x01(\x05\x12\x18\n\x10investor_unit_id\x18\x08 \x01(\t\x12\x13\n\x0blimit_price\x18\t \x01(\x01\"\xf3\x02\n\x16QueryMaxOrderVolumeRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x15\n\rinstrument_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\t\x12(\n\tdirection\x18\x04 \x01(\x0e\x32\x15.trade.tag.ActionType\x12.\n\x0boffset_flag\x18\x05 \x01(\x0e\x32\x19.trade.tag.OffsetFlagType\x12,\n\nhedge_flag\x18\x06 \x01(\x0e\x32\x18.trade.tag.HedgeFlagType\x12\x12\n\nmax_volume\x18\x07 \x01(\x05\x12\x11\n\tbroker_id\x18\x08 \x01(\t\x12\x13\n\x0binvestor_id\x18\t \x01(\t\x12\x18\n\x10investor_unit_id\x18\n \x01(\t\x12\x14\n\x0ctrading_code\x18\x0b \x01(\t\x12\x0e\n\x06volume\x18\x0c \x01(\x05\x12\x13\n\x0blimit_price\x18\r \x01(\x01\"$\n\x0cQryNoticeReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\"`\n\x0cQryNoticeRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x16\n\x0esequence_label\x18\x04 \x01(\t\"E\n\x13QryTradingNoticeReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x18\n\x10investor_unit_id\x18\x02 \x01(\t\"\xdd\x01\n\x13QryTradingNoticeRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x17\n\x0fsequence_series\x18\x04 \x01(\x05\x12\x11\n\tsend_time\x18\x05 \x01(\t\x12\x13\n\x0bsequence_no\x18\x06 \x01(\x05\x12\x15\n\rfield_content\x18\x07 \x01(\x0c\x12\x18\n\x10investor_unit_id\x18\x08 \x01(\t\x12\x16\n\x0einvestor_range\x18\t \x01(\x05\"z\n QueryCFMMCTradingAccountTokenReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x18\n\x10investor_unit_id\x18\x04 \x01(\t\"\xca\x01\n QueryCFMMCTradingAccountTokenRsp\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x04 \x01(\t\x12\x12\n\naccount_id\x18\x05 \x01(\t\x12\x0e\n\x06key_id\x18\x06 \x01(\x05\x12\r\n\x05token\x18\x07 \x01(\t\x12\x0c\n\x04\x63ode\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\tB\x06\xa2\x02\x03TFTb\x06proto3')
  ,
  dependencies=[trade_dot_trade__enum__pb2.DESCRIPTOR,])




_USERPASSWORDUPDATEREQ = _descriptor.Descriptor(
  name='UserPasswordUpdateReq',
  full_name='trade.futures.UserPasswordUpdateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.UserPasswordUpdateReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_password', full_name='trade.futures.UserPasswordUpdateReq.old_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='trade.futures.UserPasswordUpdateReq.new_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=157,
)


_USERPASSWORDUPDATERSP = _descriptor.Descriptor(
  name='UserPasswordUpdateRsp',
  full_name='trade.futures.UserPasswordUpdateRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.UserPasswordUpdateRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_password', full_name='trade.futures.UserPasswordUpdateRsp.old_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='trade.futures.UserPasswordUpdateRsp.new_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.UserPasswordUpdateRsp.broker_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.UserPasswordUpdateRsp.investor_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_id', full_name='trade.futures.UserPasswordUpdateRsp.error_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='trade.futures.UserPasswordUpdateRsp.error_msg', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='special_flag', full_name='trade.futures.UserPasswordUpdateRsp.special_flag', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.UserPasswordUpdateRsp.code', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.UserPasswordUpdateRsp.message', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voucher_no', full_name='trade.futures.UserPasswordUpdateRsp.voucher_no', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=427,
)


_QUERYINVESTORREQ = _descriptor.Descriptor(
  name='QueryInvestorReq',
  full_name='trade.futures.QueryInvestorReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryInvestorReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QueryInvestorReq.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryInvestorReq.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=509,
)


_QUERYINVESTORRSP = _descriptor.Descriptor(
  name='QueryInvestorRsp',
  full_name='trade.futures.QueryInvestorRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryInvestorRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QueryInvestorRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryInvestorRsp.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_group_id', full_name='trade.futures.QueryInvestorRsp.investor_group_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_name', full_name='trade.futures.QueryInvestorRsp.client_name', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='trade.futures.QueryInvestorRsp.is_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telephone', full_name='trade.futures.QueryInvestorRsp.telephone', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='trade.futures.QueryInvestorRsp.address', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_date', full_name='trade.futures.QueryInvestorRsp.open_date', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile', full_name='trade.futures.QueryInvestorRsp.mobile', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comm_model_id', full_name='trade.futures.QueryInvestorRsp.comm_model_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin_model_id', full_name='trade.futures.QueryInvestorRsp.margin_model_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiedi_card_no', full_name='trade.futures.QueryInvestorRsp.identifiedi_card_no', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_card_type', full_name='trade.futures.QueryInvestorRsp.id_card_type', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=856,
)


_CONFIRMSETTLEMENTINFOREQ = _descriptor.Descriptor(
  name='ConfirmSettlementInfoReq',
  full_name='trade.futures.ConfirmSettlementInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.ConfirmSettlementInfoReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.ConfirmSettlementInfoReq.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.ConfirmSettlementInfoReq.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.ConfirmSettlementInfoReq.trading_day', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.ConfirmSettlementInfoReq.account_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.ConfirmSettlementInfoReq.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=1034,
)


_CONFIRMSETTLEMENTINFORSP = _descriptor.Descriptor(
  name='ConfirmSettlementInfoRsp',
  full_name='trade.futures.ConfirmSettlementInfoRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.ConfirmSettlementInfoRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.ConfirmSettlementInfoRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.ConfirmSettlementInfoRsp.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confirm_date', full_name='trade.futures.ConfirmSettlementInfoRsp.confirm_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confirm_time', full_name='trade.futures.ConfirmSettlementInfoRsp.confirm_time', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.ConfirmSettlementInfoRsp.settlement_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.ConfirmSettlementInfoRsp.account_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.ConfirmSettlementInfoRsp.currency_id', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bill_flag', full_name='trade.futures.ConfirmSettlementInfoRsp.bill_flag', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1277,
)


_QUERYSETTLEMENTINFOREQ = _descriptor.Descriptor(
  name='QuerySettlementInfoReq',
  full_name='trade.futures.QuerySettlementInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QuerySettlementInfoReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QuerySettlementInfoReq.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QuerySettlementInfoReq.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QuerySettlementInfoReq.trading_day', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.QuerySettlementInfoReq.account_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QuerySettlementInfoReq.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='trade.futures.QuerySettlementInfoReq.start_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='trade.futures.QuerySettlementInfoReq.end_date', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1491,
)


_QUERYSETTLEMENTINFORSP = _descriptor.Descriptor(
  name='QuerySettlementInfoRsp',
  full_name='trade.futures.QuerySettlementInfoRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QuerySettlementInfoRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QuerySettlementInfoRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QuerySettlementInfoRsp.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QuerySettlementInfoRsp.trading_day', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.QuerySettlementInfoRsp.settlement_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_no', full_name='trade.futures.QuerySettlementInfoRsp.sequence_no', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='trade.futures.QuerySettlementInfoRsp.content', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.QuerySettlementInfoRsp.account_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QuerySettlementInfoRsp.currency_id', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bill_flag', full_name='trade.futures.QuerySettlementInfoRsp.bill_flag', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_size', full_name='trade.futures.QuerySettlementInfoRsp.content_size', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1494,
  serialized_end=1769,
)


_QUERYSETTLEMENTINFOCONFIRMREQ = _descriptor.Descriptor(
  name='QuerySettlementInfoConfirmReq',
  full_name='trade.futures.QuerySettlementInfoConfirmReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QuerySettlementInfoConfirmReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QuerySettlementInfoConfirmReq.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QuerySettlementInfoConfirmReq.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.QuerySettlementInfoConfirmReq.account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QuerySettlementInfoConfirmReq.currency_id', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1931,
)


_QUERYSETTLEMENTINFOCONFIRMRSP = _descriptor.Descriptor(
  name='QuerySettlementInfoConfirmRsp',
  full_name='trade.futures.QuerySettlementInfoConfirmRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QuerySettlementInfoConfirmRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QuerySettlementInfoConfirmRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QuerySettlementInfoConfirmRsp.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confirm_date', full_name='trade.futures.QuerySettlementInfoConfirmRsp.confirm_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confirm_time', full_name='trade.futures.QuerySettlementInfoConfirmRsp.confirm_time', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.QuerySettlementInfoConfirmRsp.settlement_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.QuerySettlementInfoConfirmRsp.account_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QuerySettlementInfoConfirmRsp.currency_id', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1934,
  serialized_end=2160,
)


_QUERYORDERREQ = _descriptor.Descriptor(
  name='QueryOrderReq',
  full_name='trade.futures.QueryOrderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryOrderReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryOrderReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryOrderReq.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_sys_id', full_name='trade.futures.QueryOrderReq.order_sys_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_time_start', full_name='trade.futures.QueryOrderReq.insert_time_start', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_time_end', full_name='trade.futures.QueryOrderReq.insert_time_end', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QueryOrderReq.client_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2337,
)


_QUERYREPORTREQ = _descriptor.Descriptor(
  name='QueryReportReq',
  full_name='trade.futures.QueryReportReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryReportReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryReportReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryReportReq.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='trade.futures.QueryReportReq.trade_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time_start', full_name='trade.futures.QueryReportReq.trade_time_start', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time_end', full_name='trade.futures.QueryReportReq.trade_time_end', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QueryReportReq.client_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='trade.futures.QueryReportReq.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2340,
  serialized_end=2553,
)


_QUERYASSETREQ = _descriptor.Descriptor(
  name='QueryAssetReq',
  full_name='trade.futures.QueryAssetReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryAssetReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryAssetReq.currency_id', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biz_type', full_name='trade.futures.QueryAssetReq.biz_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.QueryAssetReq.account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QueryAssetReq.client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QueryAssetReq.trading_day', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=2737,
)


_QUERYASSETRSP = _descriptor.Descriptor(
  name='QueryAssetRsp',
  full_name='trade.futures.QueryAssetRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryAssetRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_mortgage', full_name='trade.futures.QueryAssetRsp.pre_mortgage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_credit', full_name='trade.futures.QueryAssetRsp.pre_credit', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_deposit', full_name='trade.futures.QueryAssetRsp.pre_deposit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_balance', full_name='trade.futures.QueryAssetRsp.pre_balance', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_margin', full_name='trade.futures.QueryAssetRsp.pre_margin', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interest_base', full_name='trade.futures.QueryAssetRsp.interest_base', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interest', full_name='trade.futures.QueryAssetRsp.interest', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='trade.futures.QueryAssetRsp.deposit', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdraw', full_name='trade.futures.QueryAssetRsp.withdraw', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_margin', full_name='trade.futures.QueryAssetRsp.frozen_margin', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_cash', full_name='trade.futures.QueryAssetRsp.frozen_cash', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_commission', full_name='trade.futures.QueryAssetRsp.frozen_commission', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curr_margin', full_name='trade.futures.QueryAssetRsp.curr_margin', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cash_in', full_name='trade.futures.QueryAssetRsp.cash_in', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commission', full_name='trade.futures.QueryAssetRsp.commission', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit', full_name='trade.futures.QueryAssetRsp.close_profit', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit', full_name='trade.futures.QueryAssetRsp.position_profit', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance', full_name='trade.futures.QueryAssetRsp.balance', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='available', full_name='trade.futures.QueryAssetRsp.available', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdraw_quota', full_name='trade.futures.QueryAssetRsp.withdraw_quota', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reserve', full_name='trade.futures.QueryAssetRsp.reserve', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QueryAssetRsp.trading_day', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.QueryAssetRsp.settlement_id', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='credit', full_name='trade.futures.QueryAssetRsp.credit', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mortgage', full_name='trade.futures.QueryAssetRsp.mortgage', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_margin', full_name='trade.futures.QueryAssetRsp.exchange_margin', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delivery_margin', full_name='trade.futures.QueryAssetRsp.delivery_margin', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_delivery_margin', full_name='trade.futures.QueryAssetRsp.exchange_delivery_margin', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reserve_balance', full_name='trade.futures.QueryAssetRsp.reserve_balance', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryAssetRsp.currency_id', index=30,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_fund_mortgage_in', full_name='trade.futures.QueryAssetRsp.pre_fund_mortgage_in', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_fund_mortgage_out', full_name='trade.futures.QueryAssetRsp.pre_fund_mortgage_out', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fund_mortgage_in', full_name='trade.futures.QueryAssetRsp.fund_mortgage_in', index=33,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fund_mortgage_out', full_name='trade.futures.QueryAssetRsp.fund_mortgage_out', index=34,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fund_mortgage_available', full_name='trade.futures.QueryAssetRsp.fund_mortgage_available', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mortgageable_fund', full_name='trade.futures.QueryAssetRsp.mortgageable_fund', index=36,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_margin', full_name='trade.futures.QueryAssetRsp.spec_product_margin', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_frozen_margin', full_name='trade.futures.QueryAssetRsp.spec_product_frozen_margin', index=38,
      number=39, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_commission', full_name='trade.futures.QueryAssetRsp.spec_product_commission', index=39,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_frozen_commission', full_name='trade.futures.QueryAssetRsp.spec_product_frozen_commission', index=40,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_position_profit', full_name='trade.futures.QueryAssetRsp.spec_product_position_profit', index=41,
      number=42, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_close_profit', full_name='trade.futures.QueryAssetRsp.spec_product_close_profit', index=42,
      number=43, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_position_profit_by_alg', full_name='trade.futures.QueryAssetRsp.spec_product_position_profit_by_alg', index=43,
      number=44, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_product_exchange_margin', full_name='trade.futures.QueryAssetRsp.spec_product_exchange_margin', index=44,
      number=45, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biz_type', full_name='trade.futures.QueryAssetRsp.biz_type', index=45,
      number=46, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_swap', full_name='trade.futures.QueryAssetRsp.frozen_swap', index=46,
      number=47, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remain_swap', full_name='trade.futures.QueryAssetRsp.remain_swap', index=47,
      number=48, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryAssetRsp.investor_id', index=48,
      number=49, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QueryAssetRsp.client_id', index=49,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit_by_trade', full_name='trade.futures.QueryAssetRsp.close_profit_by_trade', index=50,
      number=51, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit_by_trade', full_name='trade.futures.QueryAssetRsp.position_profit_by_trade', index=51,
      number=52, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2740,
  serialized_end=4096,
)


_QUERYPOSITIONREQ = _descriptor.Descriptor(
  name='QueryPositionReq',
  full_name='trade.futures.QueryPositionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryPositionReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryPositionReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryPositionReq.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historical_date', full_name='trade.futures.QueryPositionReq.historical_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QueryPositionReq.client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4099,
  serialized_end=4227,
)


_QUERYPOSITIONRSP = _descriptor.Descriptor(
  name='QueryPositionRsp',
  full_name='trade.futures.QueryPositionRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryPositionRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryPositionRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posi_direction', full_name='trade.futures.QueryPositionRsp.posi_direction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_flag', full_name='trade.futures.QueryPositionRsp.hedge_flag', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_date', full_name='trade.futures.QueryPositionRsp.position_date', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yd_position', full_name='trade.futures.QueryPositionRsp.yd_position', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='trade.futures.QueryPositionRsp.position', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_frozen', full_name='trade.futures.QueryPositionRsp.long_frozen', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_frozen', full_name='trade.futures.QueryPositionRsp.short_frozen', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_frozen_amount', full_name='trade.futures.QueryPositionRsp.long_frozen_amount', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_frozen_amount', full_name='trade.futures.QueryPositionRsp.short_frozen_amount', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_volume', full_name='trade.futures.QueryPositionRsp.open_volume', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_volume', full_name='trade.futures.QueryPositionRsp.close_volume', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_amount', full_name='trade.futures.QueryPositionRsp.open_amount', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_amount', full_name='trade.futures.QueryPositionRsp.close_amount', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_cost', full_name='trade.futures.QueryPositionRsp.position_cost', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_margin', full_name='trade.futures.QueryPositionRsp.pre_margin', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_margin', full_name='trade.futures.QueryPositionRsp.use_margin', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_margin', full_name='trade.futures.QueryPositionRsp.frozen_margin', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_cash', full_name='trade.futures.QueryPositionRsp.frozen_cash', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_commission', full_name='trade.futures.QueryPositionRsp.frozen_commission', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cash_in', full_name='trade.futures.QueryPositionRsp.cash_in', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commission', full_name='trade.futures.QueryPositionRsp.commission', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit', full_name='trade.futures.QueryPositionRsp.close_profit', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit', full_name='trade.futures.QueryPositionRsp.position_profit', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_settlement_price', full_name='trade.futures.QueryPositionRsp.pre_settlement_price', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='trade.futures.QueryPositionRsp.settlement_price', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QueryPositionRsp.trading_day', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.QueryPositionRsp.settlement_id', index=28,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_cost', full_name='trade.futures.QueryPositionRsp.open_cost', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_margin', full_name='trade.futures.QueryPositionRsp.exchange_margin', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_position', full_name='trade.futures.QueryPositionRsp.comb_position', index=31,
      number=32, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_long_frozen', full_name='trade.futures.QueryPositionRsp.comb_long_frozen', index=32,
      number=33, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_short_frozen', full_name='trade.futures.QueryPositionRsp.comb_short_frozen', index=33,
      number=34, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit_by_date', full_name='trade.futures.QueryPositionRsp.close_profit_by_date', index=34,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit_by_trade', full_name='trade.futures.QueryPositionRsp.close_profit_by_trade', index=35,
      number=36, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='today_position', full_name='trade.futures.QueryPositionRsp.today_position', index=36,
      number=37, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin_rate_by_money', full_name='trade.futures.QueryPositionRsp.margin_rate_by_money', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin_rate_by_volume', full_name='trade.futures.QueryPositionRsp.margin_rate_by_volume', index=38,
      number=39, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strike_frozen', full_name='trade.futures.QueryPositionRsp.strike_frozen', index=39,
      number=40, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strike_frozen_amount', full_name='trade.futures.QueryPositionRsp.strike_frozen_amount', index=40,
      number=41, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abandon_frozen', full_name='trade.futures.QueryPositionRsp.abandon_frozen', index=41,
      number=42, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryPositionRsp.exchange_id', index=42,
      number=43, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yd_strike_frozen', full_name='trade.futures.QueryPositionRsp.yd_strike_frozen', index=43,
      number=44, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryPositionRsp.investor_id', index=44,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QueryPositionRsp.client_id', index=45,
      number=46, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_position', full_name='trade.futures.QueryPositionRsp.enable_position', index=46,
      number=47, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tas_position', full_name='trade.futures.QueryPositionRsp.tas_position', index=47,
      number=48, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tas_position_cost', full_name='trade.futures.QueryPositionRsp.tas_position_cost', index=48,
      number=49, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='td_enable_position', full_name='trade.futures.QueryPositionRsp.td_enable_position', index=49,
      number=50, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yd_enable_position', full_name='trade.futures.QueryPositionRsp.yd_enable_position', index=50,
      number=51, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_open_cost', full_name='trade.futures.QueryPositionRsp.average_open_cost', index=51,
      number=52, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_position_cost', full_name='trade.futures.QueryPositionRsp.average_position_cost', index=52,
      number=53, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4230,
  serialized_end=5577,
)


_QUERYPOSITIONDETAILREQ = _descriptor.Descriptor(
  name='QueryPositionDetailReq',
  full_name='trade.futures.QueryPositionDetailReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryPositionDetailReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryPositionDetailReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryPositionDetailReq.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historical_date', full_name='trade.futures.QueryPositionDetailReq.historical_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='trade.futures.QueryPositionDetailReq.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5580,
  serialized_end=5731,
)


_QUERYPOSITIONDETAILRSP = _descriptor.Descriptor(
  name='QueryPositionDetailRsp',
  full_name='trade.futures.QueryPositionDetailRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryPositionDetailRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryPositionDetailRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_type', full_name='trade.futures.QueryPositionDetailRsp.hedge_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='trade.futures.QueryPositionDetailRsp.direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_date', full_name='trade.futures.QueryPositionDetailRsp.open_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='trade.futures.QueryPositionDetailRsp.trade_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='trade.futures.QueryPositionDetailRsp.volume', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_price', full_name='trade.futures.QueryPositionDetailRsp.open_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QueryPositionDetailRsp.trading_day', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.QueryPositionDetailRsp.settlement_id', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_type', full_name='trade.futures.QueryPositionDetailRsp.trade_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_instrument_id', full_name='trade.futures.QueryPositionDetailRsp.comb_instrument_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryPositionDetailRsp.exchange_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit_by_date', full_name='trade.futures.QueryPositionDetailRsp.close_profit_by_date', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit_by_trade', full_name='trade.futures.QueryPositionDetailRsp.close_profit_by_trade', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit_by_date', full_name='trade.futures.QueryPositionDetailRsp.position_profit_by_date', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_profit_by_trade', full_name='trade.futures.QueryPositionDetailRsp.position_profit_by_trade', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin', full_name='trade.futures.QueryPositionDetailRsp.margin', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exch_margin', full_name='trade.futures.QueryPositionDetailRsp.exch_margin', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin_rate_by_money', full_name='trade.futures.QueryPositionDetailRsp.margin_rate_by_money', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margin_rate_by_volume', full_name='trade.futures.QueryPositionDetailRsp.margin_rate_by_volume', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_settlement_price', full_name='trade.futures.QueryPositionDetailRsp.last_settlement_price', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='trade.futures.QueryPositionDetailRsp.settlement_price', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_volume', full_name='trade.futures.QueryPositionDetailRsp.close_volume', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_amount', full_name='trade.futures.QueryPositionDetailRsp.close_amount', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryPositionDetailRsp.investor_id', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_date_type', full_name='trade.futures.QueryPositionDetailRsp.position_date_type', index=26,
      number=27, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_posi_type', full_name='trade.futures.QueryPositionDetailRsp.spec_posi_type', index=27,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5734,
  serialized_end=6532,
)


_QUERYCOMMISSIONRATEREQ = _descriptor.Descriptor(
  name='QueryCommissionRateReq',
  full_name='trade.futures.QueryCommissionRateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryCommissionRateReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryCommissionRateReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryCommissionRateReq.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6534,
  serialized_end=6624,
)


_QUERYCOMMISSIONRATERSP = _descriptor.Descriptor(
  name='QueryCommissionRateRsp',
  full_name='trade.futures.QueryCommissionRateRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryCommissionRateRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryCommissionRateRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_range', full_name='trade.futures.QueryCommissionRateRsp.investor_range', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_ratio_by_money', full_name='trade.futures.QueryCommissionRateRsp.open_ratio_by_money', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_ratio_by_volume', full_name='trade.futures.QueryCommissionRateRsp.open_ratio_by_volume', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_ratio_by_money', full_name='trade.futures.QueryCommissionRateRsp.close_ratio_by_money', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_ratio_by_volume', full_name='trade.futures.QueryCommissionRateRsp.close_ratio_by_volume', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_today_ratio_by_money', full_name='trade.futures.QueryCommissionRateRsp.close_today_ratio_by_money', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_today_ratio_by_volume', full_name='trade.futures.QueryCommissionRateRsp.close_today_ratio_by_volume', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryCommissionRateRsp.exchange_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biz_type', full_name='trade.futures.QueryCommissionRateRsp.biz_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryCommissionRateRsp.investor_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6627,
  serialized_end=6993,
)


_QUERYMARGINRATEREQ = _descriptor.Descriptor(
  name='QueryMarginRateReq',
  full_name='trade.futures.QueryMarginRateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryMarginRateReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryMarginRateReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_flag', full_name='trade.futures.QueryMarginRateReq.hedge_flag', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryMarginRateReq.exchange_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6996,
  serialized_end=7128,
)


_QUERYMARGINRATERSP = _descriptor.Descriptor(
  name='QueryMarginRateRsp',
  full_name='trade.futures.QueryMarginRateRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryMarginRateRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryMarginRateRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_range', full_name='trade.futures.QueryMarginRateRsp.investor_range', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_flag', full_name='trade.futures.QueryMarginRateRsp.hedge_flag', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_margin_ratio_by_money', full_name='trade.futures.QueryMarginRateRsp.long_margin_ratio_by_money', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_margin_ratio_by_volume', full_name='trade.futures.QueryMarginRateRsp.long_margin_ratio_by_volume', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_margin_ratio_by_money', full_name='trade.futures.QueryMarginRateRsp.short_margin_ratio_by_money', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_margin_ratio_by_volume', full_name='trade.futures.QueryMarginRateRsp.short_margin_ratio_by_volume', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_relative', full_name='trade.futures.QueryMarginRateRsp.is_relative', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryMarginRateRsp.exchange_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryMarginRateRsp.investor_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7131,
  serialized_end=7477,
)


_ORDERINSERTREQ = _descriptor.Descriptor(
  name='OrderInsertReq',
  full_name='trade.futures.OrderInsertReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.OrderInsertReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.OrderInsertReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.futures.OrderInsertReq.order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_price_type', full_name='trade.futures.OrderInsertReq.order_price_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='trade.futures.OrderInsertReq.direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_offset_flag', full_name='trade.futures.OrderInsertReq.comb_offset_flag', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_hedge_flag', full_name='trade.futures.OrderInsertReq.comb_hedge_flag', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='trade.futures.OrderInsertReq.limit_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_total_original', full_name='trade.futures.OrderInsertReq.volume_total_original', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_condition', full_name='trade.futures.OrderInsertReq.time_condition', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gtd_date', full_name='trade.futures.OrderInsertReq.gtd_date', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_condition', full_name='trade.futures.OrderInsertReq.volume_condition', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_volume', full_name='trade.futures.OrderInsertReq.min_volume', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contingent_condition', full_name='trade.futures.OrderInsertReq.contingent_condition', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_price', full_name='trade.futures.OrderInsertReq.stop_price', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_close_reason', full_name='trade.futures.OrderInsertReq.force_close_reason', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_force_close', full_name='trade.futures.OrderInsertReq.user_force_close', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_swap_order', full_name='trade.futures.OrderInsertReq.is_swap_order', index=17,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.OrderInsertReq.exchange_id', index=18,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.futures.OrderInsertReq.local_order_no', index=19,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.OrderInsertReq.client_id', index=20,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='trade.futures.OrderInsertReq.source', index=21,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_back_hand', full_name='trade.futures.OrderInsertReq.is_back_hand', index=22,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_change_order', full_name='trade.futures.OrderInsertReq.is_change_order', index=23,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_order_price_type', full_name='trade.futures.OrderInsertReq.new_order_price_type', index=24,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_limit_price', full_name='trade.futures.OrderInsertReq.new_limit_price', index=25,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_tick_num', full_name='trade.futures.OrderInsertReq.price_tick_num', index=26,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7480,
  serialized_end=8359,
)


_ORDERINSERTRSP = _descriptor.Descriptor(
  name='OrderInsertRsp',
  full_name='trade.futures.OrderInsertRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='trade.futures.OrderInsertRsp.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.OrderInsertRsp.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.OrderInsertRsp.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8361,
  serialized_end=8454,
)


_ORDERCANCELREQ = _descriptor.Descriptor(
  name='OrderCancelReq',
  full_name='trade.futures.OrderCancelReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.OrderCancelReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_order_no', full_name='trade.futures.OrderCancelReq.cancel_order_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.futures.OrderCancelReq.order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.OrderCancelReq.exchange_id', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_sys_id', full_name='trade.futures.OrderCancelReq.order_sys_id', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.OrderCancelReq.instrument_id', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.OrderCancelReq.investor_id', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.OrderCancelReq.client_id', index=7,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_change_order', full_name='trade.futures.OrderCancelReq.is_change_order', index=8,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_total_original', full_name='trade.futures.OrderCancelReq.volume_total_original', index=9,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_price_type', full_name='trade.futures.OrderCancelReq.order_price_type', index=10,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='trade.futures.OrderCancelReq.limit_price', index=11,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_tick_num', full_name='trade.futures.OrderCancelReq.price_tick_num', index=12,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8457,
  serialized_end=8798,
)


_ORDERCANCELRSP = _descriptor.Descriptor(
  name='OrderCancelRsp',
  full_name='trade.futures.OrderCancelRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='trade.futures.OrderCancelRsp.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.OrderCancelRsp.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.OrderCancelRsp.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8800,
  serialized_end=8893,
)


_ORDERCANCELFAILINFO = _descriptor.Descriptor(
  name='OrderCancelFailInfo',
  full_name='trade.futures.OrderCancelFailInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='trade.futures.OrderCancelFailInfo.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.OrderCancelFailInfo.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.OrderCancelFailInfo.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_order_msg', full_name='trade.futures.OrderCancelFailInfo.change_order_msg', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8895,
  serialized_end=9019,
)


_ORDERINFO = _descriptor.Descriptor(
  name='OrderInfo',
  full_name='trade.futures.OrderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.OrderInfo.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.OrderInfo.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_no', full_name='trade.futures.OrderInfo.order_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_price_type', full_name='trade.futures.OrderInfo.order_price_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='trade.futures.OrderInfo.direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_offset_flag', full_name='trade.futures.OrderInfo.comb_offset_flag', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comb_hedge_flag', full_name='trade.futures.OrderInfo.comb_hedge_flag', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='trade.futures.OrderInfo.limit_price', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_total_original', full_name='trade.futures.OrderInfo.volume_total_original', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_condition', full_name='trade.futures.OrderInfo.time_condition', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gtd_date', full_name='trade.futures.OrderInfo.gtd_date', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_condition', full_name='trade.futures.OrderInfo.volume_condition', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_volume', full_name='trade.futures.OrderInfo.min_volume', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_price', full_name='trade.futures.OrderInfo.stop_price', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_close_reason', full_name='trade.futures.OrderInfo.force_close_reason', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='trade.futures.OrderInfo.request_id', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_local_id', full_name='trade.futures.OrderInfo.order_local_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.OrderInfo.exchange_id', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_submit_status', full_name='trade.futures.OrderInfo.order_submit_status', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.OrderInfo.trading_day', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_id', full_name='trade.futures.OrderInfo.settlement_id', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_sys_id', full_name='trade.futures.OrderInfo.order_sys_id', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_status', full_name='trade.futures.OrderInfo.order_status', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='trade.futures.OrderInfo.order_type', index=23,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_traded', full_name='trade.futures.OrderInfo.volume_traded', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_total', full_name='trade.futures.OrderInfo.volume_total', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_date', full_name='trade.futures.OrderInfo.insert_date', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_time', full_name='trade.futures.OrderInfo.insert_time', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_time', full_name='trade.futures.OrderInfo.active_time', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspend_time', full_name='trade.futures.OrderInfo.suspend_time', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='trade.futures.OrderInfo.update_time', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_time', full_name='trade.futures.OrderInfo.cancel_time', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_product_info', full_name='trade.futures.OrderInfo.user_product_info', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_msg', full_name='trade.futures.OrderInfo.status_msg', index=33,
      number=34, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_force_close', full_name='trade.futures.OrderInfo.user_force_close', index=34,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_order_seq', full_name='trade.futures.OrderInfo.broker_order_seq', index=35,
      number=36, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_order_sys_id', full_name='trade.futures.OrderInfo.relative_order_sys_id', index=36,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zce_total_traded_volume', full_name='trade.futures.OrderInfo.zce_total_traded_volume', index=37,
      number=38, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_swap_order', full_name='trade.futures.OrderInfo.is_swap_order', index=38,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.OrderInfo.currency_id', index=39,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contingent_condition', full_name='trade.futures.OrderInfo.contingent_condition', index=40,
      number=41, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.OrderInfo.code', index=41,
      number=42, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.OrderInfo.message', index=42,
      number=43, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.OrderInfo.investor_id', index=43,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_order_no', full_name='trade.futures.OrderInfo.local_order_no', index=44,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocation_mark', full_name='trade.futures.OrderInfo.revocation_mark', index=45,
      number=46, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.OrderInfo.client_id', index=46,
      number=47, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='back_hand_message', full_name='trade.futures.OrderInfo.back_hand_message', index=47,
      number=48, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_volume_total_original', full_name='trade.futures.OrderInfo.new_volume_total_original', index=48,
      number=49, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_limit_price', full_name='trade.futures.OrderInfo.new_limit_price', index=49,
      number=50, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_order_price_type', full_name='trade.futures.OrderInfo.new_order_price_type', index=50,
      number=51, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_change_order', full_name='trade.futures.OrderInfo.is_change_order', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_order_message', full_name='trade.futures.OrderInfo.change_order_message', index=52,
      number=53, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_tick_num', full_name='trade.futures.OrderInfo.price_tick_num', index=53,
      number=54, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9022,
  serialized_end=10590,
)


_TRADEREPORTINFO = _descriptor.Descriptor(
  name='TradeReportInfo',
  full_name='trade.futures.TradeReportInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.TradeReportInfo.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.TradeReportInfo.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.TradeReportInfo.exchange_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='trade.futures.TradeReportInfo.trade_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='trade.futures.TradeReportInfo.direction', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_sys_id', full_name='trade.futures.TradeReportInfo.order_sys_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_flag', full_name='trade.futures.TradeReportInfo.offset_flag', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_flag', full_name='trade.futures.TradeReportInfo.hedge_flag', index=7,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.futures.TradeReportInfo.price', index=8,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='trade.futures.TradeReportInfo.volume', index=9,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_date', full_name='trade.futures.TradeReportInfo.trade_date', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.futures.TradeReportInfo.trade_time', index=11,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_type', full_name='trade.futures.TradeReportInfo.trade_type', index=12,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_source', full_name='trade.futures.TradeReportInfo.price_source', index=13,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.TradeReportInfo.trading_day', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.TradeReportInfo.investor_id', index=15,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.TradeReportInfo.client_id', index=16,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commission', full_name='trade.futures.TradeReportInfo.commission', index=17,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_profit', full_name='trade.futures.TradeReportInfo.close_profit', index=18,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_order_price_type', full_name='trade.futures.TradeReportInfo.new_order_price_type', index=19,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_back_hand', full_name='trade.futures.TradeReportInfo.is_back_hand', index=20,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_total_original', full_name='trade.futures.TradeReportInfo.volume_total_original', index=21,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_tick_num', full_name='trade.futures.TradeReportInfo.price_tick_num', index=22,
      number=54, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_limit_price', full_name='trade.futures.TradeReportInfo.new_limit_price', index=23,
      number=55, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='back_hand_message', full_name='trade.futures.TradeReportInfo.back_hand_message', index=24,
      number=56, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_order_message', full_name='trade.futures.TradeReportInfo.change_order_message', index=25,
      number=57, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='trade.futures.TradeReportInfo.settlement_price', index=26,
      number=58, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_date', full_name='trade.futures.TradeReportInfo.open_date', index=27,
      number=59, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_price', full_name='trade.futures.TradeReportInfo.open_price', index=28,
      number=60, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10593,
  serialized_end=11403,
)


_INSTRUMENTTRADESTATUSINFO = _descriptor.Descriptor(
  name='InstrumentTradeStatusInfo',
  full_name='trade.futures.InstrumentTradeStatusInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='trade.futures.InstrumentTradeStatusInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.InstrumentTradeStatusInfo.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.InstrumentTradeStatusInfo.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_status', full_name='trade.futures.InstrumentTradeStatusInfo.instrument_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enter_time', full_name='trade.futures.InstrumentTradeStatusInfo.enter_time', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_enter_time', full_name='trade.futures.InstrumentTradeStatusInfo.local_enter_time', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11406,
  serialized_end=11624,
)


_QUERYCONTRACTBANKREQ = _descriptor.Descriptor(
  name='QueryContractBankReq',
  full_name='trade.futures.QueryContractBankReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryContractBankReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11626,
  serialized_end=11670,
)


_QUERYCONTRACTBANKRSP = _descriptor.Descriptor(
  name='QueryContractBankRsp',
  full_name='trade.futures.QueryContractBankRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.QueryContractBankRsp.bank_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.QueryContractBankRsp.bank_branch_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_name', full_name='trade.futures.QueryContractBankRsp.bank_name', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryContractBankRsp.investor_key', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11672,
  serialized_end=11776,
)


_QUERYACCOUNTREGISTERREQ = _descriptor.Descriptor(
  name='QueryAccountregisterReq',
  full_name='trade.futures.QueryAccountregisterReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryAccountregisterReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryAccountregisterReq.currency_id', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11778,
  serialized_end=11871,
)


_QUERYACCOUNTREGISTERRSP = _descriptor.Descriptor(
  name='QueryAccountregisterRsp',
  full_name='trade.futures.QueryAccountregisterRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.QueryAccountregisterRsp.bank_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.QueryAccountregisterRsp.bank_branch_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.QueryAccountregisterRsp.bank_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.QueryAccountregisterRsp.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_name', full_name='trade.futures.QueryAccountregisterRsp.customer_name', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryAccountregisterRsp.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reg_date', full_name='trade.futures.QueryAccountregisterRsp.reg_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_date', full_name='trade.futures.QueryAccountregisterRsp.out_date', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_date', full_name='trade.futures.QueryAccountregisterRsp.trade_date', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiedi_card_no', full_name='trade.futures.QueryAccountregisterRsp.identifiedi_card_no', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cust_type', full_name='trade.futures.QueryAccountregisterRsp.cust_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_or_destroy', full_name='trade.futures.QueryAccountregisterRsp.open_or_destroy', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_card_type', full_name='trade.futures.QueryAccountregisterRsp.id_card_type', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_acc_type', full_name='trade.futures.QueryAccountregisterRsp.bank_acc_type', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryAccountregisterRsp.investor_key', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_name', full_name='trade.futures.QueryAccountregisterRsp.bank_name', index=15,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_branch_id', full_name='trade.futures.QueryAccountregisterRsp.broker_branch_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11874,
  serialized_end=12399,
)


_QUERYTRANSFERSERIALREQ = _descriptor.Descriptor(
  name='QueryTransferSerialReq',
  full_name='trade.futures.QueryTransferSerialReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryTransferSerialReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.QueryTransferSerialReq.bank_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryTransferSerialReq.currency_id', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='trade.futures.QueryTransferSerialReq.start_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='trade.futures.QueryTransferSerialReq.end_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12402,
  serialized_end=12549,
)


_QUERYTRANSFERSERIALRSP = _descriptor.Descriptor(
  name='QueryTransferSerialRsp',
  full_name='trade.futures.QueryTransferSerialRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.QueryTransferSerialRsp.bank_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.QueryTransferSerialRsp.bank_branch_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.QueryTransferSerialRsp.bank_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.QueryTransferSerialRsp.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.futures.QueryTransferSerialRsp.trade_amount', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryTransferSerialRsp.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_date', full_name='trade.futures.QueryTransferSerialRsp.trade_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QueryTransferSerialRsp.trading_day', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_serial', full_name='trade.futures.QueryTransferSerialRsp.bank_serial', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiedi_card_no', full_name='trade.futures.QueryTransferSerialRsp.identifiedi_card_no', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plate_serial', full_name='trade.futures.QueryTransferSerialRsp.plate_serial', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future_serial', full_name='trade.futures.QueryTransferSerialRsp.future_serial', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cust_fee', full_name='trade.futures.QueryTransferSerialRsp.cust_fee', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_fee', full_name='trade.futures.QueryTransferSerialRsp.broker_fee', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_name', full_name='trade.futures.QueryTransferSerialRsp.bank_name', index=14,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_card_type', full_name='trade.futures.QueryTransferSerialRsp.id_card_type', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.futures.QueryTransferSerialRsp.trade_time', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_direction', full_name='trade.futures.QueryTransferSerialRsp.transfer_direction', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_id', full_name='trade.futures.QueryTransferSerialRsp.error_id', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='trade.futures.QueryTransferSerialRsp.error_msg', index=19,
      number=20, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='trade.futures.QueryTransferSerialRsp.results', index=20,
      number=21, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryTransferSerialRsp.investor_key', index=21,
      number=22, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12552,
  serialized_end=13117,
)


_QUERYBANKACCOUNTMONEYREQ = _descriptor.Descriptor(
  name='QueryBankAccountMoneyReq',
  full_name='trade.futures.QueryBankAccountMoneyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryBankAccountMoneyReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.QueryBankAccountMoneyReq.bank_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.QueryBankAccountMoneyReq.bank_branch_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_password', full_name='trade.futures.QueryBankAccountMoneyReq.bank_password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='trade.futures.QueryBankAccountMoneyReq.password', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryBankAccountMoneyReq.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_branch_id', full_name='trade.futures.QueryBankAccountMoneyReq.broker_branch_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.QueryBankAccountMoneyReq.account', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.QueryBankAccountMoneyReq.bank_account', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13120,
  serialized_end=13361,
)


_QUERYBANKACCOUNTMONEYRSP = _descriptor.Descriptor(
  name='QueryBankAccountMoneyRsp',
  full_name='trade.futures.QueryBankAccountMoneyRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_branch_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.QueryBankAccountMoneyRsp.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.QueryBankAccountMoneyRsp.currency_id', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_date', full_name='trade.futures.QueryBankAccountMoneyRsp.trade_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.QueryBankAccountMoneyRsp.trading_day', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_serial', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_serial', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiedi_card_no', full_name='trade.futures.QueryBankAccountMoneyRsp.identifiedi_card_no', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_code', full_name='trade.futures.QueryBankAccountMoneyRsp.trade_code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plate_serial', full_name='trade.futures.QueryBankAccountMoneyRsp.plate_serial', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future_serial', full_name='trade.futures.QueryBankAccountMoneyRsp.future_serial', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_use_amount', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_use_amount', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_fetch_amount', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_fetch_amount', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_name', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_name', index=14,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.futures.QueryBankAccountMoneyRsp.trade_time', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_card_type', full_name='trade.futures.QueryBankAccountMoneyRsp.id_card_type', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_pwd_flag', full_name='trade.futures.QueryBankAccountMoneyRsp.bank_pwd_flag', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secu_pwd_flag', full_name='trade.futures.QueryBankAccountMoneyRsp.secu_pwd_flag', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_id', full_name='trade.futures.QueryBankAccountMoneyRsp.error_id', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='trade.futures.QueryBankAccountMoneyRsp.error_msg', index=20,
      number=21, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.QueryBankAccountMoneyRsp.code', index=21,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.QueryBankAccountMoneyRsp.message', index=22,
      number=26, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='trade.futures.QueryBankAccountMoneyRsp.results', index=23,
      number=27, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryBankAccountMoneyRsp.investor_key', index=24,
      number=28, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13364,
  serialized_end=14013,
)


_FROMBANKTOFUTUREREQ = _descriptor.Descriptor(
  name='FromBankToFutureReq',
  full_name='trade.futures.FromBankToFutureReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.FromBankToFutureReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.FromBankToFutureReq.bank_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.FromBankToFutureReq.bank_branch_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_password', full_name='trade.futures.FromBankToFutureReq.bank_password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='trade.futures.FromBankToFutureReq.password', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.futures.FromBankToFutureReq.trade_amount', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.FromBankToFutureReq.currency_id', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_branch_id', full_name='trade.futures.FromBankToFutureReq.broker_branch_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.FromBankToFutureReq.account', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.FromBankToFutureReq.bank_account', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14016,
  serialized_end=14274,
)


_FROMBANKTOFUTURERSP = _descriptor.Descriptor(
  name='FromBankToFutureRsp',
  full_name='trade.futures.FromBankToFutureRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.FromBankToFutureRsp.bank_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.FromBankToFutureRsp.bank_branch_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.FromBankToFutureRsp.bank_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.FromBankToFutureRsp.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.futures.FromBankToFutureRsp.trade_amount', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.FromBankToFutureRsp.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_date', full_name='trade.futures.FromBankToFutureRsp.trade_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.FromBankToFutureRsp.trading_day', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiedi_card_no', full_name='trade.futures.FromBankToFutureRsp.identifiedi_card_no', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_serial', full_name='trade.futures.FromBankToFutureRsp.bank_serial', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plate_serial', full_name='trade.futures.FromBankToFutureRsp.plate_serial', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future_serial', full_name='trade.futures.FromBankToFutureRsp.future_serial', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cust_fee', full_name='trade.futures.FromBankToFutureRsp.cust_fee', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_fee', full_name='trade.futures.FromBankToFutureRsp.broker_fee', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future_fetch_amount', full_name='trade.futures.FromBankToFutureRsp.future_fetch_amount', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_status', full_name='trade.futures.FromBankToFutureRsp.transfer_status', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_pwd_flag', full_name='trade.futures.FromBankToFutureRsp.bank_pwd_flag', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secu_pwd_flag', full_name='trade.futures.FromBankToFutureRsp.secu_pwd_flag', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_card_type', full_name='trade.futures.FromBankToFutureRsp.id_card_type', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_direction', full_name='trade.futures.FromBankToFutureRsp.transfer_direction', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.futures.FromBankToFutureRsp.trade_time', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_id', full_name='trade.futures.FromBankToFutureRsp.error_id', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='trade.futures.FromBankToFutureRsp.error_msg', index=22,
      number=23, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.FromBankToFutureRsp.code', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.FromBankToFutureRsp.message', index=24,
      number=25, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.FromBankToFutureRsp.investor_key', index=25,
      number=26, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14277,
  serialized_end=15005,
)


_FROMFUTURETOBANKREQ = _descriptor.Descriptor(
  name='FromFutureToBankReq',
  full_name='trade.futures.FromFutureToBankReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.FromFutureToBankReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.FromFutureToBankReq.bank_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.FromFutureToBankReq.bank_branch_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='trade.futures.FromFutureToBankReq.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.futures.FromFutureToBankReq.trade_amount', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.FromFutureToBankReq.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_branch_id', full_name='trade.futures.FromFutureToBankReq.broker_branch_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_password', full_name='trade.futures.FromFutureToBankReq.bank_password', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_direction', full_name='trade.futures.FromFutureToBankReq.transfer_direction', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.FromFutureToBankReq.account', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.FromFutureToBankReq.bank_account', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15008,
  serialized_end=15321,
)


_FROMFUTURETOBANKRSP = _descriptor.Descriptor(
  name='FromFutureToBankRsp',
  full_name='trade.futures.FromFutureToBankRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bank_id', full_name='trade.futures.FromFutureToBankRsp.bank_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_branch_id', full_name='trade.futures.FromFutureToBankRsp.bank_branch_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_account', full_name='trade.futures.FromFutureToBankRsp.bank_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='trade.futures.FromFutureToBankRsp.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_amount', full_name='trade.futures.FromFutureToBankRsp.trade_amount', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.FromFutureToBankRsp.currency_id', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_date', full_name='trade.futures.FromFutureToBankRsp.trade_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_day', full_name='trade.futures.FromFutureToBankRsp.trading_day', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiedi_card_no', full_name='trade.futures.FromFutureToBankRsp.identifiedi_card_no', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_serial', full_name='trade.futures.FromFutureToBankRsp.bank_serial', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plate_serial', full_name='trade.futures.FromFutureToBankRsp.plate_serial', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future_serial', full_name='trade.futures.FromFutureToBankRsp.future_serial', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cust_fee', full_name='trade.futures.FromFutureToBankRsp.cust_fee', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_fee', full_name='trade.futures.FromFutureToBankRsp.broker_fee', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='future_fetch_amount', full_name='trade.futures.FromFutureToBankRsp.future_fetch_amount', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_status', full_name='trade.futures.FromFutureToBankRsp.transfer_status', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bank_pwd_flag', full_name='trade.futures.FromFutureToBankRsp.bank_pwd_flag', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secu_pwd_flag', full_name='trade.futures.FromFutureToBankRsp.secu_pwd_flag', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_card_type', full_name='trade.futures.FromFutureToBankRsp.id_card_type', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_direction', full_name='trade.futures.FromFutureToBankRsp.transfer_direction', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_time', full_name='trade.futures.FromFutureToBankRsp.trade_time', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_id', full_name='trade.futures.FromFutureToBankRsp.error_id', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='trade.futures.FromFutureToBankRsp.error_msg', index=22,
      number=23, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.FromFutureToBankRsp.code', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.FromFutureToBankRsp.message', index=24,
      number=25, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.FromFutureToBankRsp.investor_key', index=25,
      number=26, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15324,
  serialized_end=16052,
)


_TRADINGACCOUNTPASSWORDUPDATEREQ = _descriptor.Descriptor(
  name='TradingAccountPasswordUpdateReq',
  full_name='trade.futures.TradingAccountPasswordUpdateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.TradingAccountPasswordUpdateReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_password', full_name='trade.futures.TradingAccountPasswordUpdateReq.old_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='trade.futures.TradingAccountPasswordUpdateReq.new_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.TradingAccountPasswordUpdateReq.currency_id', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16055,
  serialized_end=16200,
)


_TRADINGACCOUNTPASSWORDUPDATERSP = _descriptor.Descriptor(
  name='TradingAccountPasswordUpdateRsp',
  full_name='trade.futures.TradingAccountPasswordUpdateRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.TradingAccountPasswordUpdateRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.TradingAccountPasswordUpdateRsp.account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_password', full_name='trade.futures.TradingAccountPasswordUpdateRsp.old_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='trade.futures.TradingAccountPasswordUpdateRsp.new_password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='trade.futures.TradingAccountPasswordUpdateRsp.currency_id', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_id', full_name='trade.futures.TradingAccountPasswordUpdateRsp.error_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='trade.futures.TradingAccountPasswordUpdateRsp.error_msg', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='special_flag', full_name='trade.futures.TradingAccountPasswordUpdateRsp.special_flag', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.TradingAccountPasswordUpdateRsp.code', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.TradingAccountPasswordUpdateRsp.message', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voucher_no', full_name='trade.futures.TradingAccountPasswordUpdateRsp.voucher_no', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16203,
  serialized_end=16506,
)


_QRYTRADINGCODEREQ = _descriptor.Descriptor(
  name='QryTradingCodeReq',
  full_name='trade.futures.QryTradingCodeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QryTradingCodeReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QryTradingCodeReq.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QryTradingCodeReq.client_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='trade.futures.QryTradingCodeReq.is_active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id_type', full_name='trade.futures.QryTradingCodeReq.client_id_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QryTradingCodeReq.investor_unit_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16509,
  serialized_end=16688,
)


_QRYTRADINGCODERSP = _descriptor.Descriptor(
  name='QryTradingCodeRsp',
  full_name='trade.futures.QryTradingCodeRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QryTradingCodeRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QryTradingCodeRsp.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QryTradingCodeRsp.broker_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='trade.futures.QryTradingCodeRsp.client_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='trade.futures.QryTradingCodeRsp.is_active', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biz_type', full_name='trade.futures.QryTradingCodeRsp.biz_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id_type', full_name='trade.futures.QryTradingCodeRsp.client_id_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QryTradingCodeRsp.investor_unit_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_code', full_name='trade.futures.QryTradingCodeRsp.trading_code', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16691,
  serialized_end=16949,
)


_QUERYMAXORDERVOLUMEREQ = _descriptor.Descriptor(
  name='QueryMaxOrderVolumeReq',
  full_name='trade.futures.QueryMaxOrderVolumeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryMaxOrderVolumeReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryMaxOrderVolumeReq.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryMaxOrderVolumeReq.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='trade.futures.QueryMaxOrderVolumeReq.direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_flag', full_name='trade.futures.QueryMaxOrderVolumeReq.offset_flag', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_flag', full_name='trade.futures.QueryMaxOrderVolumeReq.hedge_flag', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_volume', full_name='trade.futures.QueryMaxOrderVolumeReq.max_volume', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QueryMaxOrderVolumeReq.investor_unit_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='trade.futures.QueryMaxOrderVolumeReq.limit_price', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16952,
  serialized_end=17245,
)


_QUERYMAXORDERVOLUMERSP = _descriptor.Descriptor(
  name='QueryMaxOrderVolumeRsp',
  full_name='trade.futures.QueryMaxOrderVolumeRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryMaxOrderVolumeRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument_id', full_name='trade.futures.QueryMaxOrderVolumeRsp.instrument_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='trade.futures.QueryMaxOrderVolumeRsp.exchange_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='trade.futures.QueryMaxOrderVolumeRsp.direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_flag', full_name='trade.futures.QueryMaxOrderVolumeRsp.offset_flag', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hedge_flag', full_name='trade.futures.QueryMaxOrderVolumeRsp.hedge_flag', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_volume', full_name='trade.futures.QueryMaxOrderVolumeRsp.max_volume', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QueryMaxOrderVolumeRsp.broker_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryMaxOrderVolumeRsp.investor_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QueryMaxOrderVolumeRsp.investor_unit_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trading_code', full_name='trade.futures.QueryMaxOrderVolumeRsp.trading_code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='trade.futures.QueryMaxOrderVolumeRsp.volume', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='trade.futures.QueryMaxOrderVolumeRsp.limit_price', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17248,
  serialized_end=17619,
)


_QRYNOTICEREQ = _descriptor.Descriptor(
  name='QryNoticeReq',
  full_name='trade.futures.QryNoticeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QryNoticeReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17621,
  serialized_end=17657,
)


_QRYNOTICERSP = _descriptor.Descriptor(
  name='QryNoticeRsp',
  full_name='trade.futures.QryNoticeRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QryNoticeRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QryNoticeRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='trade.futures.QryNoticeRsp.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_label', full_name='trade.futures.QryNoticeRsp.sequence_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17659,
  serialized_end=17755,
)


_QRYTRADINGNOTICEREQ = _descriptor.Descriptor(
  name='QryTradingNoticeReq',
  full_name='trade.futures.QryTradingNoticeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QryTradingNoticeReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QryTradingNoticeReq.investor_unit_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17757,
  serialized_end=17826,
)


_QRYTRADINGNOTICERSP = _descriptor.Descriptor(
  name='QryTradingNoticeRsp',
  full_name='trade.futures.QryTradingNoticeRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QryTradingNoticeRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QryTradingNoticeRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QryTradingNoticeRsp.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_series', full_name='trade.futures.QryTradingNoticeRsp.sequence_series', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_time', full_name='trade.futures.QryTradingNoticeRsp.send_time', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_no', full_name='trade.futures.QryTradingNoticeRsp.sequence_no', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_content', full_name='trade.futures.QryTradingNoticeRsp.field_content', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QryTradingNoticeRsp.investor_unit_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_range', full_name='trade.futures.QryTradingNoticeRsp.investor_range', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17829,
  serialized_end=18050,
)


_QUERYCFMMCTRADINGACCOUNTTOKENREQ = _descriptor.Descriptor(
  name='QueryCFMMCTradingAccountTokenReq',
  full_name='trade.futures.QueryCFMMCTradingAccountTokenReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryCFMMCTradingAccountTokenReq.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenReq.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenReq.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_unit_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenReq.investor_unit_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18052,
  serialized_end=18174,
)


_QUERYCFMMCTRADINGACCOUNTTOKENRSP = _descriptor.Descriptor(
  name='QueryCFMMCTradingAccountTokenRsp',
  full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='investor_key', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.investor_key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='investor_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.investor_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.participant_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.account_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_id', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.key_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.token', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.code', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.futures.QueryCFMMCTradingAccountTokenRsp.message', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18177,
  serialized_end=18379,
)

_USERPASSWORDUPDATERSP.fields_by_name['special_flag'].enum_type = trade_dot_trade__enum__pb2._SPECIALFLAGTYPE
_QUERYINVESTORRSP.fields_by_name['id_card_type'].enum_type = trade_dot_trade__enum__pb2._IDCARDTYPETYPE
_CONFIRMSETTLEMENTINFOREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_CONFIRMSETTLEMENTINFORSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYSETTLEMENTINFOREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYSETTLEMENTINFORSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYSETTLEMENTINFOCONFIRMREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYSETTLEMENTINFOCONFIRMRSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYREPORTREQ.fields_by_name['status'].enum_type = trade_dot_trade__enum__pb2._TRADESTATUSTYPE
_QUERYASSETREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYASSETREQ.fields_by_name['biz_type'].enum_type = trade_dot_trade__enum__pb2._BIZTYPE
_QUERYASSETRSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYASSETRSP.fields_by_name['biz_type'].enum_type = trade_dot_trade__enum__pb2._BIZTYPE
_QUERYPOSITIONRSP.fields_by_name['posi_direction'].enum_type = trade_dot_trade__enum__pb2._POSIDIRECTIONTYPE
_QUERYPOSITIONRSP.fields_by_name['hedge_flag'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
_QUERYPOSITIONDETAILREQ.fields_by_name['type'].enum_type = trade_dot_trade__enum__pb2._QUERYTYPE
_QUERYPOSITIONDETAILRSP.fields_by_name['hedge_type'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
_QUERYPOSITIONDETAILRSP.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_QUERYPOSITIONDETAILRSP.fields_by_name['trade_type'].enum_type = trade_dot_trade__enum__pb2._TRADETYPETYPE
_QUERYPOSITIONDETAILRSP.fields_by_name['position_date_type'].enum_type = trade_dot_trade__enum__pb2._POSITIONDATETYPE
_QUERYCOMMISSIONRATERSP.fields_by_name['biz_type'].enum_type = trade_dot_trade__enum__pb2._BIZTYPE
_QUERYMARGINRATEREQ.fields_by_name['hedge_flag'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
_QUERYMARGINRATERSP.fields_by_name['hedge_flag'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
_ORDERINSERTREQ.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_ORDERINSERTREQ.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINSERTREQ.fields_by_name['time_condition'].enum_type = trade_dot_trade__enum__pb2._TIMECONDITIONTYPE
_ORDERINSERTREQ.fields_by_name['volume_condition'].enum_type = trade_dot_trade__enum__pb2._VOLUMECONDITIONTYPE
_ORDERINSERTREQ.fields_by_name['contingent_condition'].enum_type = trade_dot_trade__enum__pb2._CONTINGENTCONDITIONTYPE
_ORDERINSERTREQ.fields_by_name['force_close_reason'].enum_type = trade_dot_trade__enum__pb2._FORCECLOSEREASONTYPE
_ORDERINSERTREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_ORDERINSERTREQ.fields_by_name['new_order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_ORDERINSERTRSP.fields_by_name['order'].message_type = _ORDERINSERTREQ
_ORDERCANCELREQ.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_ORDERCANCELRSP.fields_by_name['order'].message_type = _ORDERCANCELREQ
_ORDERCANCELFAILINFO.fields_by_name['order'].message_type = _ORDERCANCELREQ
_ORDERINFO.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_ORDERINFO.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_ORDERINFO.fields_by_name['time_condition'].enum_type = trade_dot_trade__enum__pb2._TIMECONDITIONTYPE
_ORDERINFO.fields_by_name['volume_condition'].enum_type = trade_dot_trade__enum__pb2._VOLUMECONDITIONTYPE
_ORDERINFO.fields_by_name['force_close_reason'].enum_type = trade_dot_trade__enum__pb2._FORCECLOSEREASONTYPE
_ORDERINFO.fields_by_name['order_status'].enum_type = trade_dot_trade__enum__pb2._ORDERSTATUSTYPE
_ORDERINFO.fields_by_name['order_type'].enum_type = trade_dot_trade__enum__pb2._ORDERTYPE
_ORDERINFO.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_ORDERINFO.fields_by_name['contingent_condition'].enum_type = trade_dot_trade__enum__pb2._CONTINGENTCONDITIONTYPE
_ORDERINFO.fields_by_name['new_order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_TRADEREPORTINFO.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_TRADEREPORTINFO.fields_by_name['offset_flag'].enum_type = trade_dot_trade__enum__pb2._OFFSETFLAGTYPE
_TRADEREPORTINFO.fields_by_name['hedge_flag'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
_TRADEREPORTINFO.fields_by_name['trade_type'].enum_type = trade_dot_trade__enum__pb2._TRADETYPETYPE
_TRADEREPORTINFO.fields_by_name['price_source'].enum_type = trade_dot_trade__enum__pb2._PRICESOURCETYPE
_TRADEREPORTINFO.fields_by_name['new_order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_INSTRUMENTTRADESTATUSINFO.fields_by_name['type'].enum_type = trade_dot_trade__enum__pb2._INSTRUMENTTYPE
_INSTRUMENTTRADESTATUSINFO.fields_by_name['instrument_status'].enum_type = trade_dot_trade__enum__pb2._INSTRUMENTSTATUSTYPE
_QUERYACCOUNTREGISTERREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYACCOUNTREGISTERRSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYACCOUNTREGISTERRSP.fields_by_name['cust_type'].enum_type = trade_dot_trade__enum__pb2._CUSTTYPETYPE
_QUERYACCOUNTREGISTERRSP.fields_by_name['open_or_destroy'].enum_type = trade_dot_trade__enum__pb2._OPENORDESTROYTYPE
_QUERYACCOUNTREGISTERRSP.fields_by_name['id_card_type'].enum_type = trade_dot_trade__enum__pb2._IDCARDTYPETYPE
_QUERYACCOUNTREGISTERRSP.fields_by_name['bank_acc_type'].enum_type = trade_dot_trade__enum__pb2._BANKACCTYPETYPE
_QUERYTRANSFERSERIALREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYTRANSFERSERIALRSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYTRANSFERSERIALRSP.fields_by_name['id_card_type'].enum_type = trade_dot_trade__enum__pb2._IDCARDTYPETYPE
_QUERYTRANSFERSERIALRSP.fields_by_name['transfer_direction'].enum_type = trade_dot_trade__enum__pb2._TRANSDIRECTION
_QUERYBANKACCOUNTMONEYREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYBANKACCOUNTMONEYRSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_QUERYBANKACCOUNTMONEYRSP.fields_by_name['id_card_type'].enum_type = trade_dot_trade__enum__pb2._IDCARDTYPETYPE
_QUERYBANKACCOUNTMONEYRSP.fields_by_name['bank_pwd_flag'].enum_type = trade_dot_trade__enum__pb2._PWDFLAGTYPE
_QUERYBANKACCOUNTMONEYRSP.fields_by_name['secu_pwd_flag'].enum_type = trade_dot_trade__enum__pb2._PWDFLAGTYPE
_FROMBANKTOFUTUREREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_FROMBANKTOFUTURERSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_FROMBANKTOFUTURERSP.fields_by_name['transfer_status'].enum_type = trade_dot_trade__enum__pb2._STATUSTYPE
_FROMBANKTOFUTURERSP.fields_by_name['bank_pwd_flag'].enum_type = trade_dot_trade__enum__pb2._PWDFLAGTYPE
_FROMBANKTOFUTURERSP.fields_by_name['secu_pwd_flag'].enum_type = trade_dot_trade__enum__pb2._PWDFLAGTYPE
_FROMBANKTOFUTURERSP.fields_by_name['id_card_type'].enum_type = trade_dot_trade__enum__pb2._IDCARDTYPETYPE
_FROMBANKTOFUTURERSP.fields_by_name['transfer_direction'].enum_type = trade_dot_trade__enum__pb2._TRANSDIRECTION
_FROMFUTURETOBANKREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_FROMFUTURETOBANKREQ.fields_by_name['transfer_direction'].enum_type = trade_dot_trade__enum__pb2._TRANSDIRECTION
_FROMFUTURETOBANKRSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_FROMFUTURETOBANKRSP.fields_by_name['transfer_status'].enum_type = trade_dot_trade__enum__pb2._STATUSTYPE
_FROMFUTURETOBANKRSP.fields_by_name['bank_pwd_flag'].enum_type = trade_dot_trade__enum__pb2._PWDFLAGTYPE
_FROMFUTURETOBANKRSP.fields_by_name['secu_pwd_flag'].enum_type = trade_dot_trade__enum__pb2._PWDFLAGTYPE
_FROMFUTURETOBANKRSP.fields_by_name['id_card_type'].enum_type = trade_dot_trade__enum__pb2._IDCARDTYPETYPE
_FROMFUTURETOBANKRSP.fields_by_name['transfer_direction'].enum_type = trade_dot_trade__enum__pb2._TRANSDIRECTION
_TRADINGACCOUNTPASSWORDUPDATEREQ.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_TRADINGACCOUNTPASSWORDUPDATERSP.fields_by_name['currency_id'].enum_type = trade_dot_trade__enum__pb2._CURRENCYTYPE
_TRADINGACCOUNTPASSWORDUPDATERSP.fields_by_name['special_flag'].enum_type = trade_dot_trade__enum__pb2._SPECIALFLAGTYPE
_QRYTRADINGCODEREQ.fields_by_name['client_id_type'].enum_type = trade_dot_trade__enum__pb2._CLIENTIDTYPETYPE
_QRYTRADINGCODERSP.fields_by_name['biz_type'].enum_type = trade_dot_trade__enum__pb2._BIZTYPE
_QRYTRADINGCODERSP.fields_by_name['client_id_type'].enum_type = trade_dot_trade__enum__pb2._CLIENTIDTYPETYPE
_QUERYMAXORDERVOLUMEREQ.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_QUERYMAXORDERVOLUMEREQ.fields_by_name['offset_flag'].enum_type = trade_dot_trade__enum__pb2._OFFSETFLAGTYPE
_QUERYMAXORDERVOLUMEREQ.fields_by_name['hedge_flag'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
_QUERYMAXORDERVOLUMERSP.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_QUERYMAXORDERVOLUMERSP.fields_by_name['offset_flag'].enum_type = trade_dot_trade__enum__pb2._OFFSETFLAGTYPE
_QUERYMAXORDERVOLUMERSP.fields_by_name['hedge_flag'].enum_type = trade_dot_trade__enum__pb2._HEDGEFLAGTYPE
DESCRIPTOR.message_types_by_name['UserPasswordUpdateReq'] = _USERPASSWORDUPDATEREQ
DESCRIPTOR.message_types_by_name['UserPasswordUpdateRsp'] = _USERPASSWORDUPDATERSP
DESCRIPTOR.message_types_by_name['QueryInvestorReq'] = _QUERYINVESTORREQ
DESCRIPTOR.message_types_by_name['QueryInvestorRsp'] = _QUERYINVESTORRSP
DESCRIPTOR.message_types_by_name['ConfirmSettlementInfoReq'] = _CONFIRMSETTLEMENTINFOREQ
DESCRIPTOR.message_types_by_name['ConfirmSettlementInfoRsp'] = _CONFIRMSETTLEMENTINFORSP
DESCRIPTOR.message_types_by_name['QuerySettlementInfoReq'] = _QUERYSETTLEMENTINFOREQ
DESCRIPTOR.message_types_by_name['QuerySettlementInfoRsp'] = _QUERYSETTLEMENTINFORSP
DESCRIPTOR.message_types_by_name['QuerySettlementInfoConfirmReq'] = _QUERYSETTLEMENTINFOCONFIRMREQ
DESCRIPTOR.message_types_by_name['QuerySettlementInfoConfirmRsp'] = _QUERYSETTLEMENTINFOCONFIRMRSP
DESCRIPTOR.message_types_by_name['QueryOrderReq'] = _QUERYORDERREQ
DESCRIPTOR.message_types_by_name['QueryReportReq'] = _QUERYREPORTREQ
DESCRIPTOR.message_types_by_name['QueryAssetReq'] = _QUERYASSETREQ
DESCRIPTOR.message_types_by_name['QueryAssetRsp'] = _QUERYASSETRSP
DESCRIPTOR.message_types_by_name['QueryPositionReq'] = _QUERYPOSITIONREQ
DESCRIPTOR.message_types_by_name['QueryPositionRsp'] = _QUERYPOSITIONRSP
DESCRIPTOR.message_types_by_name['QueryPositionDetailReq'] = _QUERYPOSITIONDETAILREQ
DESCRIPTOR.message_types_by_name['QueryPositionDetailRsp'] = _QUERYPOSITIONDETAILRSP
DESCRIPTOR.message_types_by_name['QueryCommissionRateReq'] = _QUERYCOMMISSIONRATEREQ
DESCRIPTOR.message_types_by_name['QueryCommissionRateRsp'] = _QUERYCOMMISSIONRATERSP
DESCRIPTOR.message_types_by_name['QueryMarginRateReq'] = _QUERYMARGINRATEREQ
DESCRIPTOR.message_types_by_name['QueryMarginRateRsp'] = _QUERYMARGINRATERSP
DESCRIPTOR.message_types_by_name['OrderInsertReq'] = _ORDERINSERTREQ
DESCRIPTOR.message_types_by_name['OrderInsertRsp'] = _ORDERINSERTRSP
DESCRIPTOR.message_types_by_name['OrderCancelReq'] = _ORDERCANCELREQ
DESCRIPTOR.message_types_by_name['OrderCancelRsp'] = _ORDERCANCELRSP
DESCRIPTOR.message_types_by_name['OrderCancelFailInfo'] = _ORDERCANCELFAILINFO
DESCRIPTOR.message_types_by_name['OrderInfo'] = _ORDERINFO
DESCRIPTOR.message_types_by_name['TradeReportInfo'] = _TRADEREPORTINFO
DESCRIPTOR.message_types_by_name['InstrumentTradeStatusInfo'] = _INSTRUMENTTRADESTATUSINFO
DESCRIPTOR.message_types_by_name['QueryContractBankReq'] = _QUERYCONTRACTBANKREQ
DESCRIPTOR.message_types_by_name['QueryContractBankRsp'] = _QUERYCONTRACTBANKRSP
DESCRIPTOR.message_types_by_name['QueryAccountregisterReq'] = _QUERYACCOUNTREGISTERREQ
DESCRIPTOR.message_types_by_name['QueryAccountregisterRsp'] = _QUERYACCOUNTREGISTERRSP
DESCRIPTOR.message_types_by_name['QueryTransferSerialReq'] = _QUERYTRANSFERSERIALREQ
DESCRIPTOR.message_types_by_name['QueryTransferSerialRsp'] = _QUERYTRANSFERSERIALRSP
DESCRIPTOR.message_types_by_name['QueryBankAccountMoneyReq'] = _QUERYBANKACCOUNTMONEYREQ
DESCRIPTOR.message_types_by_name['QueryBankAccountMoneyRsp'] = _QUERYBANKACCOUNTMONEYRSP
DESCRIPTOR.message_types_by_name['FromBankToFutureReq'] = _FROMBANKTOFUTUREREQ
DESCRIPTOR.message_types_by_name['FromBankToFutureRsp'] = _FROMBANKTOFUTURERSP
DESCRIPTOR.message_types_by_name['FromFutureToBankReq'] = _FROMFUTURETOBANKREQ
DESCRIPTOR.message_types_by_name['FromFutureToBankRsp'] = _FROMFUTURETOBANKRSP
DESCRIPTOR.message_types_by_name['TradingAccountPasswordUpdateReq'] = _TRADINGACCOUNTPASSWORDUPDATEREQ
DESCRIPTOR.message_types_by_name['TradingAccountPasswordUpdateRsp'] = _TRADINGACCOUNTPASSWORDUPDATERSP
DESCRIPTOR.message_types_by_name['QryTradingCodeReq'] = _QRYTRADINGCODEREQ
DESCRIPTOR.message_types_by_name['QryTradingCodeRsp'] = _QRYTRADINGCODERSP
DESCRIPTOR.message_types_by_name['QueryMaxOrderVolumeReq'] = _QUERYMAXORDERVOLUMEREQ
DESCRIPTOR.message_types_by_name['QueryMaxOrderVolumeRsp'] = _QUERYMAXORDERVOLUMERSP
DESCRIPTOR.message_types_by_name['QryNoticeReq'] = _QRYNOTICEREQ
DESCRIPTOR.message_types_by_name['QryNoticeRsp'] = _QRYNOTICERSP
DESCRIPTOR.message_types_by_name['QryTradingNoticeReq'] = _QRYTRADINGNOTICEREQ
DESCRIPTOR.message_types_by_name['QryTradingNoticeRsp'] = _QRYTRADINGNOTICERSP
DESCRIPTOR.message_types_by_name['QueryCFMMCTradingAccountTokenReq'] = _QUERYCFMMCTRADINGACCOUNTTOKENREQ
DESCRIPTOR.message_types_by_name['QueryCFMMCTradingAccountTokenRsp'] = _QUERYCFMMCTRADINGACCOUNTTOKENRSP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserPasswordUpdateReq = _reflection.GeneratedProtocolMessageType('UserPasswordUpdateReq', (_message.Message,), {
  'DESCRIPTOR' : _USERPASSWORDUPDATEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.UserPasswordUpdateReq)
  })
_sym_db.RegisterMessage(UserPasswordUpdateReq)

UserPasswordUpdateRsp = _reflection.GeneratedProtocolMessageType('UserPasswordUpdateRsp', (_message.Message,), {
  'DESCRIPTOR' : _USERPASSWORDUPDATERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.UserPasswordUpdateRsp)
  })
_sym_db.RegisterMessage(UserPasswordUpdateRsp)

QueryInvestorReq = _reflection.GeneratedProtocolMessageType('QueryInvestorReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINVESTORREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryInvestorReq)
  })
_sym_db.RegisterMessage(QueryInvestorReq)

QueryInvestorRsp = _reflection.GeneratedProtocolMessageType('QueryInvestorRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINVESTORRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryInvestorRsp)
  })
_sym_db.RegisterMessage(QueryInvestorRsp)

ConfirmSettlementInfoReq = _reflection.GeneratedProtocolMessageType('ConfirmSettlementInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMSETTLEMENTINFOREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.ConfirmSettlementInfoReq)
  })
_sym_db.RegisterMessage(ConfirmSettlementInfoReq)

ConfirmSettlementInfoRsp = _reflection.GeneratedProtocolMessageType('ConfirmSettlementInfoRsp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMSETTLEMENTINFORSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.ConfirmSettlementInfoRsp)
  })
_sym_db.RegisterMessage(ConfirmSettlementInfoRsp)

QuerySettlementInfoReq = _reflection.GeneratedProtocolMessageType('QuerySettlementInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSETTLEMENTINFOREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QuerySettlementInfoReq)
  })
_sym_db.RegisterMessage(QuerySettlementInfoReq)

QuerySettlementInfoRsp = _reflection.GeneratedProtocolMessageType('QuerySettlementInfoRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSETTLEMENTINFORSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QuerySettlementInfoRsp)
  })
_sym_db.RegisterMessage(QuerySettlementInfoRsp)

QuerySettlementInfoConfirmReq = _reflection.GeneratedProtocolMessageType('QuerySettlementInfoConfirmReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSETTLEMENTINFOCONFIRMREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QuerySettlementInfoConfirmReq)
  })
_sym_db.RegisterMessage(QuerySettlementInfoConfirmReq)

QuerySettlementInfoConfirmRsp = _reflection.GeneratedProtocolMessageType('QuerySettlementInfoConfirmRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSETTLEMENTINFOCONFIRMRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QuerySettlementInfoConfirmRsp)
  })
_sym_db.RegisterMessage(QuerySettlementInfoConfirmRsp)

QueryOrderReq = _reflection.GeneratedProtocolMessageType('QueryOrderReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORDERREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryOrderReq)
  })
_sym_db.RegisterMessage(QueryOrderReq)

QueryReportReq = _reflection.GeneratedProtocolMessageType('QueryReportReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryReportReq)
  })
_sym_db.RegisterMessage(QueryReportReq)

QueryAssetReq = _reflection.GeneratedProtocolMessageType('QueryAssetReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYASSETREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryAssetReq)
  })
_sym_db.RegisterMessage(QueryAssetReq)

QueryAssetRsp = _reflection.GeneratedProtocolMessageType('QueryAssetRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYASSETRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryAssetRsp)
  })
_sym_db.RegisterMessage(QueryAssetRsp)

QueryPositionReq = _reflection.GeneratedProtocolMessageType('QueryPositionReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryPositionReq)
  })
_sym_db.RegisterMessage(QueryPositionReq)

QueryPositionRsp = _reflection.GeneratedProtocolMessageType('QueryPositionRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryPositionRsp)
  })
_sym_db.RegisterMessage(QueryPositionRsp)

QueryPositionDetailReq = _reflection.GeneratedProtocolMessageType('QueryPositionDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONDETAILREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryPositionDetailReq)
  })
_sym_db.RegisterMessage(QueryPositionDetailReq)

QueryPositionDetailRsp = _reflection.GeneratedProtocolMessageType('QueryPositionDetailRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONDETAILRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryPositionDetailRsp)
  })
_sym_db.RegisterMessage(QueryPositionDetailRsp)

QueryCommissionRateReq = _reflection.GeneratedProtocolMessageType('QueryCommissionRateReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOMMISSIONRATEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryCommissionRateReq)
  })
_sym_db.RegisterMessage(QueryCommissionRateReq)

QueryCommissionRateRsp = _reflection.GeneratedProtocolMessageType('QueryCommissionRateRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOMMISSIONRATERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryCommissionRateRsp)
  })
_sym_db.RegisterMessage(QueryCommissionRateRsp)

QueryMarginRateReq = _reflection.GeneratedProtocolMessageType('QueryMarginRateReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARGINRATEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryMarginRateReq)
  })
_sym_db.RegisterMessage(QueryMarginRateReq)

QueryMarginRateRsp = _reflection.GeneratedProtocolMessageType('QueryMarginRateRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARGINRATERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryMarginRateRsp)
  })
_sym_db.RegisterMessage(QueryMarginRateRsp)

OrderInsertReq = _reflection.GeneratedProtocolMessageType('OrderInsertReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINSERTREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.OrderInsertReq)
  })
_sym_db.RegisterMessage(OrderInsertReq)

OrderInsertRsp = _reflection.GeneratedProtocolMessageType('OrderInsertRsp', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINSERTRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.OrderInsertRsp)
  })
_sym_db.RegisterMessage(OrderInsertRsp)

OrderCancelReq = _reflection.GeneratedProtocolMessageType('OrderCancelReq', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.OrderCancelReq)
  })
_sym_db.RegisterMessage(OrderCancelReq)

OrderCancelRsp = _reflection.GeneratedProtocolMessageType('OrderCancelRsp', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.OrderCancelRsp)
  })
_sym_db.RegisterMessage(OrderCancelRsp)

OrderCancelFailInfo = _reflection.GeneratedProtocolMessageType('OrderCancelFailInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELFAILINFO,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.OrderCancelFailInfo)
  })
_sym_db.RegisterMessage(OrderCancelFailInfo)

OrderInfo = _reflection.GeneratedProtocolMessageType('OrderInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINFO,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.OrderInfo)
  })
_sym_db.RegisterMessage(OrderInfo)

TradeReportInfo = _reflection.GeneratedProtocolMessageType('TradeReportInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRADEREPORTINFO,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.TradeReportInfo)
  })
_sym_db.RegisterMessage(TradeReportInfo)

InstrumentTradeStatusInfo = _reflection.GeneratedProtocolMessageType('InstrumentTradeStatusInfo', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTTRADESTATUSINFO,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.InstrumentTradeStatusInfo)
  })
_sym_db.RegisterMessage(InstrumentTradeStatusInfo)

QueryContractBankReq = _reflection.GeneratedProtocolMessageType('QueryContractBankReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTBANKREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryContractBankReq)
  })
_sym_db.RegisterMessage(QueryContractBankReq)

QueryContractBankRsp = _reflection.GeneratedProtocolMessageType('QueryContractBankRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTBANKRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryContractBankRsp)
  })
_sym_db.RegisterMessage(QueryContractBankRsp)

QueryAccountregisterReq = _reflection.GeneratedProtocolMessageType('QueryAccountregisterReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACCOUNTREGISTERREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryAccountregisterReq)
  })
_sym_db.RegisterMessage(QueryAccountregisterReq)

QueryAccountregisterRsp = _reflection.GeneratedProtocolMessageType('QueryAccountregisterRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACCOUNTREGISTERRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryAccountregisterRsp)
  })
_sym_db.RegisterMessage(QueryAccountregisterRsp)

QueryTransferSerialReq = _reflection.GeneratedProtocolMessageType('QueryTransferSerialReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRANSFERSERIALREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryTransferSerialReq)
  })
_sym_db.RegisterMessage(QueryTransferSerialReq)

QueryTransferSerialRsp = _reflection.GeneratedProtocolMessageType('QueryTransferSerialRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRANSFERSERIALRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryTransferSerialRsp)
  })
_sym_db.RegisterMessage(QueryTransferSerialRsp)

QueryBankAccountMoneyReq = _reflection.GeneratedProtocolMessageType('QueryBankAccountMoneyReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANKACCOUNTMONEYREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryBankAccountMoneyReq)
  })
_sym_db.RegisterMessage(QueryBankAccountMoneyReq)

QueryBankAccountMoneyRsp = _reflection.GeneratedProtocolMessageType('QueryBankAccountMoneyRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANKACCOUNTMONEYRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryBankAccountMoneyRsp)
  })
_sym_db.RegisterMessage(QueryBankAccountMoneyRsp)

FromBankToFutureReq = _reflection.GeneratedProtocolMessageType('FromBankToFutureReq', (_message.Message,), {
  'DESCRIPTOR' : _FROMBANKTOFUTUREREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.FromBankToFutureReq)
  })
_sym_db.RegisterMessage(FromBankToFutureReq)

FromBankToFutureRsp = _reflection.GeneratedProtocolMessageType('FromBankToFutureRsp', (_message.Message,), {
  'DESCRIPTOR' : _FROMBANKTOFUTURERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.FromBankToFutureRsp)
  })
_sym_db.RegisterMessage(FromBankToFutureRsp)

FromFutureToBankReq = _reflection.GeneratedProtocolMessageType('FromFutureToBankReq', (_message.Message,), {
  'DESCRIPTOR' : _FROMFUTURETOBANKREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.FromFutureToBankReq)
  })
_sym_db.RegisterMessage(FromFutureToBankReq)

FromFutureToBankRsp = _reflection.GeneratedProtocolMessageType('FromFutureToBankRsp', (_message.Message,), {
  'DESCRIPTOR' : _FROMFUTURETOBANKRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.FromFutureToBankRsp)
  })
_sym_db.RegisterMessage(FromFutureToBankRsp)

TradingAccountPasswordUpdateReq = _reflection.GeneratedProtocolMessageType('TradingAccountPasswordUpdateReq', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGACCOUNTPASSWORDUPDATEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.TradingAccountPasswordUpdateReq)
  })
_sym_db.RegisterMessage(TradingAccountPasswordUpdateReq)

TradingAccountPasswordUpdateRsp = _reflection.GeneratedProtocolMessageType('TradingAccountPasswordUpdateRsp', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGACCOUNTPASSWORDUPDATERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.TradingAccountPasswordUpdateRsp)
  })
_sym_db.RegisterMessage(TradingAccountPasswordUpdateRsp)

QryTradingCodeReq = _reflection.GeneratedProtocolMessageType('QryTradingCodeReq', (_message.Message,), {
  'DESCRIPTOR' : _QRYTRADINGCODEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QryTradingCodeReq)
  })
_sym_db.RegisterMessage(QryTradingCodeReq)

QryTradingCodeRsp = _reflection.GeneratedProtocolMessageType('QryTradingCodeRsp', (_message.Message,), {
  'DESCRIPTOR' : _QRYTRADINGCODERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QryTradingCodeRsp)
  })
_sym_db.RegisterMessage(QryTradingCodeRsp)

QueryMaxOrderVolumeReq = _reflection.GeneratedProtocolMessageType('QueryMaxOrderVolumeReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMAXORDERVOLUMEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryMaxOrderVolumeReq)
  })
_sym_db.RegisterMessage(QueryMaxOrderVolumeReq)

QueryMaxOrderVolumeRsp = _reflection.GeneratedProtocolMessageType('QueryMaxOrderVolumeRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMAXORDERVOLUMERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryMaxOrderVolumeRsp)
  })
_sym_db.RegisterMessage(QueryMaxOrderVolumeRsp)

QryNoticeReq = _reflection.GeneratedProtocolMessageType('QryNoticeReq', (_message.Message,), {
  'DESCRIPTOR' : _QRYNOTICEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QryNoticeReq)
  })
_sym_db.RegisterMessage(QryNoticeReq)

QryNoticeRsp = _reflection.GeneratedProtocolMessageType('QryNoticeRsp', (_message.Message,), {
  'DESCRIPTOR' : _QRYNOTICERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QryNoticeRsp)
  })
_sym_db.RegisterMessage(QryNoticeRsp)

QryTradingNoticeReq = _reflection.GeneratedProtocolMessageType('QryTradingNoticeReq', (_message.Message,), {
  'DESCRIPTOR' : _QRYTRADINGNOTICEREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QryTradingNoticeReq)
  })
_sym_db.RegisterMessage(QryTradingNoticeReq)

QryTradingNoticeRsp = _reflection.GeneratedProtocolMessageType('QryTradingNoticeRsp', (_message.Message,), {
  'DESCRIPTOR' : _QRYTRADINGNOTICERSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QryTradingNoticeRsp)
  })
_sym_db.RegisterMessage(QryTradingNoticeRsp)

QueryCFMMCTradingAccountTokenReq = _reflection.GeneratedProtocolMessageType('QueryCFMMCTradingAccountTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCFMMCTRADINGACCOUNTTOKENREQ,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryCFMMCTradingAccountTokenReq)
  })
_sym_db.RegisterMessage(QueryCFMMCTradingAccountTokenReq)

QueryCFMMCTradingAccountTokenRsp = _reflection.GeneratedProtocolMessageType('QueryCFMMCTradingAccountTokenRsp', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCFMMCTRADINGACCOUNTTOKENRSP,
  '__module__' : 'trade.trade_futures_pb2'
  # @@protoc_insertion_point(class_scope:trade.futures.QueryCFMMCTradingAccountTokenRsp)
  })
_sym_db.RegisterMessage(QueryCFMMCTradingAccountTokenRsp)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
